#include <iostream>
#include <vector>
#include <algorithm>

int64_t n, m;
std::vector<char> board;

void input_board() {
	std::cin >> n >> m;
	board.resize(n * m);
	for (int64_t i = 0; i < n; ++i) {
		for (int64_t j = 0; j < m; ++j) {
			std::cin >> board[i * m + j];
		}
	}
}

void left() {
	for (int64_t i = 0; i < n; ++i) {
		int64_t new_j = 0;
		for (int64_t j = 0; j < m; ++j) {
			if (board[i * m + j] != '.') {
				board[i * m + new_j] = std::exchange(board[i * m + j], '.');
				++new_j;
			}
		}
	}
}

void right() {
	for (int64_t i = 0; i < n; ++i) {
		int64_t new_j = m - 1;
		for (int64_t j = m - 1; j >= 0; --j) {
			if (board[i * m + j] != '.') {
				board[i * m + new_j] = std::exchange(board[i * m + j], '.');
				--new_j;
			}
		}
	}
}

void up() {
	for (int64_t j = 0; j < m; ++j) {
		int64_t new_i = 0;
		for (int64_t i = 0; i < n; ++i) {
			if (board[i * m + j] != '.') {
				board[new_i * m + j] = std::exchange(board[i * m + j], '.');
				++new_i;
			}
		}
	}
}

void down() {
	for (int64_t j = 0; j < m; ++j) {
		int64_t new_i = n - 1;
		for (int64_t i = n - 1; i >= 0; --i) {
			if (board[i * m + j] != '.') {
				board[new_i * m + j] = std::exchange(board[i * m + j], '.');
				--new_i;
			}
		}
	}
}

void print_board() {
	for (int64_t i = 0; i < n; ++i) {
		for (int64_t j = 0; j < m; ++j) {
			std::cout << board[i * m + j];
		}
		std::cout << '\n';
	}
}

std::string simplify_queries(std::string_view queries) {
	std::string res;
	res.reserve(queries.size());

	std::vector<char> hs, vs;
	hs.reserve(queries.size());
	vs.reserve(queries.size());
	for (char q : queries) {
		if (q == 'L' || q == 'R') {
			while (!res.empty() && (res.back() == 'L' || res.back() == 'R')) {
				res.pop_back();
				hs.pop_back();
			}

			if (hs.empty() || q != hs.back()) {
				res.push_back(q);
				hs.push_back(q);
			}
		} else {
			while (!res.empty() && (res.back() == 'U' || res.back() == 'D')) {
				res.pop_back();
				vs.pop_back();
			}

			if (vs.empty() || q != vs.back()) {
				res.push_back(q);
				vs.push_back(q);
			}
		} 
	}

	return res;
}

int main() {
	int64_t t;
	std::cin >> t;

	for (int64_t i = 0; i < t; ++i) {
		input_board();

		std::string queries;
		std::cin >> queries;

		queries = simplify_queries(queries);

		for (char q : queries) {
			switch (q) {
			case 'L': left(); break;
			case 'R': right(); break;
			case 'U': up(); break;
			case 'D': down(); break;
			default: break;
			}
		}

		print_board();
	}
}
