#include <iostream>
#include <vector>
#include <algorithm>
#include <numeric>
#include <cstdint>

template <typename T>
struct Board {
	T filler;
	int64_t n, m;
	std::vector<T> board;

	void input() {
		std::cin >> n >> m;
		board.resize(n * m);
		for (int64_t i = 0; i < n; ++i) {
			for (int64_t j = 0; j < m; ++j) {
				std::cin >> board[i * m + j];
			}
		}
	}

	void left() {
		for (int64_t i = 0; i < n; ++i) {
			int64_t new_j = 0;
			for (int64_t j = 0; j < m; ++j) {
				if (board[i * m + j] != filler) {
					board[i * m + new_j] = std::exchange(board[i * m + j], filler);
					++new_j;
				}
			}
		}
	}

	void right() {
		for (int64_t i = 0; i < n; ++i) {
			int64_t new_j = m - 1;
			for (int64_t j = m - 1; j >= 0; --j) {
				if (board[i * m + j] != filler) {
					board[i * m + new_j] = std::exchange(board[i * m + j], filler);
					--new_j;
				}
			}
		}
	}

	void up() {
		for (int64_t j = 0; j < m; ++j) {
			int64_t new_i = 0;
			for (int64_t i = 0; i < n; ++i) {
				if (board[i * m + j] != filler) {
					board[new_i * m + j] = std::exchange(board[i * m + j], filler);
					++new_i;
				}
			}
		}
	}

	void down() {
		for (int64_t j = 0; j < m; ++j) {
			int64_t new_i = n - 1;
			for (int64_t i = n - 1; i >= 0; --i) {
				if (board[i * m + j] != filler) {
					board[new_i * m + j] = std::exchange(board[i * m + j], filler);
					--new_i;
				}
			}
		}
	}

	void print() {
		for (int64_t i = 0; i < n; ++i) {
			for (int64_t j = 0; j < m; ++j) {
				std::cout << board[i * m + j];
			}
			std::cout << '\n';
		}
	}

	Board<int64_t> make_perm_board() {
		Board<int64_t> res;
		res.n = n;
		res.m = m;
		res.filler = -1;
		res.board.resize(n * m, res.filler);

		int64_t label = 0;
		for (int64_t i = 0; i < n; ++i) {
			for (int64_t j = 0; j < m; ++j) {
				if (board[i * m + j] == filler) {
					res.board[i * m + j] = res.filler;
				} else {
					res.board[i * m + j] = label;
					label++;
				}
			}
		}
		return res;
	}

	std::vector<T> get_all() {
		std::vector<T> res;
		res.reserve(n * m);

		for (int64_t i = 0; i < n; ++i) {
			for (int64_t j = 0; j < m; ++j) {
				if (board[i * m + j] != filler) {
					res.push_back(board[i * m + j]);
				}
			}
		}
		return res;
	}

	void apply_perm(const std::vector<int64_t>& perm) {
		auto all = get_all();

		int64_t index = 0;
		for (int64_t i = 0; i < n; ++i) {
			for (int64_t j = 0; j < m; ++j) {
				if (board[i * m + j] != filler) {
					board[i * m + j] = all[perm[index]];
					++index;
				}
			}
		}
	}

	void apply(char op) {
		switch (op) {
		case 'L': left(); break;
		case 'R': right(); break;
		case 'U': up(); break;
		case 'D': down(); break;
		default: break;
		}
	}
};

std::vector<int64_t> perm_pow(const std::vector<int64_t>& perm, int64_t p) {
	if (p == 0) {
		std::vector<int64_t> res(perm.size());
		std::iota(res.begin(), res.end(), 0);
		return res;
	}

	if (p % 2 == 1) {
		std::vector<int64_t> res = perm_pow(perm, p - 1);
		for (int64_t& i : res) {
			i = perm[i];
		}
		return res;
	} else {
		std::vector<int64_t> half_res = perm_pow(perm, p / 2);
		std::vector<int64_t> res(half_res.size());
		for (int64_t i = 0; i < half_res.size(); ++i) {
			res[i] = half_res[half_res[i]];
		}
		return res;
	}
}

std::string simplify_queries(std::string_view queries) {
	std::string res;
	res.reserve(queries.size());

	std::vector<char> hs, vs;
	hs.reserve(queries.size());
	vs.reserve(queries.size());
	for (char q : queries) {
		if (q == 'L' || q == 'R') {
			while (!res.empty() && (res.back() == 'L' || res.back() == 'R')) {
				res.pop_back();
				hs.pop_back();
			}

			if (hs.empty() || q != hs.back()) {
				res.push_back(q);
				hs.push_back(q);
			}
		}
		else {
			while (!res.empty() && (res.back() == 'U' || res.back() == 'D')) {
				res.pop_back();
				vs.pop_back();
			}

			if (vs.empty() || q != vs.back()) {
				res.push_back(q);
				vs.push_back(q);
			}
		}
	}

	return res;
}

int main() {
	int64_t t;
	std::cin >> t;

	for (int64_t i = 0; i < t; ++i) {
		Board<char> board;
		board.filler = '.';
		board.input();

		std::string queries;
		std::cin >> queries;

		queries = simplify_queries(queries);

		for (int64_t i = 0; i < 2 && i < queries.size(); ++i) {
			board.apply(queries[i]);
		}

		if (queries.size() <= 2) {
			board.print();
			continue;
		}

		auto perm_board = board.make_perm_board();
		for (int64_t i = 0; i < 4 && i + 2 < queries.size(); ++i) {
			perm_board.apply(queries[i + 2]);
		}

		auto perm = perm_board.get_all();
		perm = perm_pow(perm, (queries.size() - 2) / 4);
		board.apply_perm(perm);

		for (int64_t i = queries.size() - (queries.size() - 2) % 4; i < queries.size(); ++i) {
			board.apply(queries[i]);
		}

		board.print();
	}
}
