#include <iostream>
#include <vector>
#include <unordered_map>
#include <unordered_set>
#include <algorithm>

struct Event {
	int64_t t;
	int64_t l;
	int64_t r;
	int64_t y;
};

std::vector<Event> events;

void input_events() {
	int64_t n;
	std::cin >> n;

	events.clear();
	events.reserve(2 * n);
	for (int64_t i = 0; i < n; ++i) {
		int64_t x1, x2, y1, y2;
		std::cin >> x1 >> y1 >> x2 >> y2;

		events.push_back(Event{  1ll, x1, x2 + 1, y1     });
		events.push_back(Event{ -1ll, x1, x2 + 1, y2 + 1 });
	}

	std::sort(events.begin(), events.end(), [](const auto& le, const auto& re) {
		return le.y < re.y;
	});
}

std::vector<int64_t> x_comp;
std::vector<int64_t> y_comp;

void compress() {
	for (auto [t, l, r, y] : events) {
		x_comp.push_back(l);
		x_comp.push_back(r);
		y_comp.push_back(y);
	}

	std::sort(x_comp.begin(), x_comp.end());
	std::sort(y_comp.begin(), y_comp.end());

	for (auto& [t, l, r, y] : events) {
		l = std::lower_bound(x_comp.begin(), x_comp.end(), l) - x_comp.begin();
		r = std::lower_bound(x_comp.begin(), x_comp.end(), r) - x_comp.begin();
		y = std::lower_bound(y_comp.begin(), y_comp.end(), y) - y_comp.begin();
	}
}

const int64_t max_x = 1'000'000;

std::unordered_map<int64_t, int64_t> count;
std::unordered_map<int64_t, int64_t> max_cont;
std::unordered_map<int64_t, int64_t> cur_cont;
std::unordered_set<int64_t> cur;
std::unordered_set<int64_t> prev;

void handle_seg(int64_t l, int64_t r, int64_t dy) {
	count[l * max_x + r] += dy;

	if (prev.count(l * max_x + r)) {
		cur_cont[l * max_x + r] += dy;
	} else {
		cur_cont[l * max_x + r] = dy;
	}
	max_cont[l * max_x + r] = std::max(cur_cont[l * max_x + r], max_cont[l * max_x + r]);

	cur.insert(l * max_x + r);
}

std::vector<int64_t> point_counts;

void reset_segs() {
	point_counts.assign(x_comp.size(), 0);
}

void handle_segs(int64_t dy) {
	int64_t start = -1;
	for (int64_t i = 0; i < point_counts.size(); ++i) {
		if (start != -1 && point_counts[i] == 0) {
			handle_seg(start, i, dy);
			start = -1;
		} else if (start == -1 && point_counts[i] != 0) {
			start = i;
		}
	}
}

void add_seg(int64_t l, int64_t r) {
	for (int64_t i = l; i < r; ++i) {
		++point_counts[i];
	}
}

void rem_seg(int64_t l, int64_t r) {
	for (int64_t i = l; i < r; ++i) {
		--point_counts[i];
	}
}

void scan() {
	reset_segs();
	count.clear();
	max_cont.clear();
	cur_cont.clear();
	cur.clear();
	prev.clear();

	for (int64_t i = 0; i + 1 < events.size(); ++i) {
		auto [t, l, r, y] = events[i];

		if (t == 1) {
			add_seg(l, r);
		} else {
			rem_seg(l, r);
		}

		handle_segs(y_comp[events[i + 1].y] - y_comp[y]);

		prev = cur;
		cur.clear();
	}
}

void print_stat() {
	int64_t n_results = 0;
	for (auto [key, count] : count) {
		if (count != 0) {
			++n_results;
		}
	}

	std::cout << n_results << '\n';
	for (auto [key, count] : count) {
		if (count != 0) {
			std::cout << x_comp[key / max_x] << ' ' << x_comp[key % max_x] - 1 << ' ' << count << ' ' << max_cont[key] << '\n';
		}
	}
}

int main() {
	int64_t t;
	std::cin >> t;

	for (int64_t i = 0; i < t; ++i) {
		input_events();
		compress();
		scan();
		print_stat();
	}
}
