#include <iostream>
#include <vector>
#include <map>
#include <algorithm>
using namespace std;
using ll = long long;
const ll INF = 1e18+7;
struct SegmentTree
{
	struct Node
	{
		ll mx=-INF;
		Node(ll val = -INF) : mx(val) {}
	};
	vector<Node> tree; vector<ll> push;
	int n;
	int L(int v) { return 2 * v + 1; };
	int R(int v) { return 2 * v + 2; };
	Node F(const Node& l, const Node& r)
	{
		Node x;
		x.mx = max(l.mx, r.mx);
		return x;
	}
	void Push(int v)
	{
		tree[L(v)].mx += push[v];
		push[L(v)] += push[v];
		tree[R(v)].mx += push[v];
		push[R(v)] += push[v];
		push[v] = 0;
	}
	void Build(vector<ll>& a)
	{
		n = a.size();
		tree.resize(4 * n);
		push.resize(4 * n);
		Build(a, 0, 0, n);
	}
	void Build(vector<ll>& a, int v, int l, int r)
	{
		if (r - l == 1)
		{
			tree[v] = Node(a[l]);
			return;
		}
		int mid = (r + l) / 2;
		Build(a, L(v), l, mid);
		Build(a, R(v), mid, r);
		tree[v] = F(tree[L(v)], tree[R(v)]);
	}
	void Set(int l, ll x)
	{
		Set(0, 0, n, l, n, x);
	}
	void Set(int v, int l, int r, int ql, int qr, ll x)
	{
		if (r <= ql || qr <= l)
		{
			return;
		}
		if (ql <= l && r <= qr)
		{
			tree[v].mx += x;
			push[v] += x;
			return;
		}
		int mid = (r + l) / 2;
		Push(v);
		Set(L(v), l, mid, ql, qr, x);
		Set(R(v), mid, r, ql, qr, x);
		tree[v] = F(tree[L(v)], tree[R(v)]);
	}
	ll Get() 
	{
		return tree[0].mx;
	}
};

int main()
{
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	cout.tie(0);
	int n, m, c, p;
	cin >> n >> m >> c >> p;
	vector<pair<int, int>> a(n+m);
	vector<ll> b;
	b.reserve(m);
	ll cnt = 0;
	for (int i = 0; i < n + m; i++)
	{
		int t; ll h;
		cin >> t >> h;
		a[i] = { t,h };
		if (t == 1)
		{
			cnt += h;
		}
		else
		{
			b.push_back(h + cnt-1);
		}
	}
	sort(b.begin(), b.end());
	b.resize(unique(b.begin(), b.end()) - b.begin());
	map<ll, int> to;
	int bsz = b.size();
	for (int i = 0; i < bsz; i++) to[b[i]] = i;
	vector<ll> r(bsz);
	for (int i = 0; i < bsz; i++)
	{
		r[i] = -b[i] * c;
	}
	SegmentTree tree;
	tree.Build(r);
	cnt = 0;
	for (int i = 0; i < n + m; i++)
	{
		auto& [t, h] = a[i];
		if (t == 1)
		{
			cnt += h;
		}
		else
		{
			tree.Set(to[h+cnt-1], p);
		}
	}
	cout << tree.Get() << '\n';
}
