#include <bits/stdc++.h>

using namespace std;
using ll = long long;

mt19937 rnd(228);

struct Node {
    pair<int, int> key; // l, r
    int prior = 0, l = 0, r = 0;
    ll added = 0, tag = 0;
    Node() = default;
    Node(pair<int, int> k) : key(k), prior(rnd()), l(0), r(0), added(0), tag(0) {}
};

constexpr int N = 2e5 + 7;

Node t[N];
int t_sz = 1;

int create(Node v) {
    int res = t_sz;
    t[res] = v;
    return res;
}

void apply_x(int x, ll tg) {
    if (x) {
        t[x].added += tg;
        t[x].tag += tg;
    }
}

void push(int x) {
    if (t[x].tag) {
        apply_x(t[x].l, t[x].tag);
        apply_x(t[x].r, t[x].tag);
        t[x].tag = 0;
    }
}

int merge(int x, int y) {
    if (!x || !y) {
        return x | y;
    }
    push(x), push(y);
    if (t[x].prior > t[y].prior) {
        t[x].r = merge(t[x].r, y);
        return x;
    } else {
        t[y].l = merge(x, t[y].l);
        return y;
    }
}

pair<int, int> split(int root, pair<int, int> key) { // l <= key
    if (!root) {
        return {};
    }
    push(root);
    if (t[root].key > key) {
        auto [l, r] = split(t[root].l, key);
        t[root].l = r;
        return {l, root};
    } else {
        auto [l, r] = split(t[root].r, key);
        t[root].r = l;
        return {root, r};
    }
}

pair<int, int> rightest_key(int root) {
    if (!root) {
        return {-1, -1};
    }
    if (t[root].r) {
        return rightest_key(t[root].r);
    } else {
        return t[root].key;
    }
}

void clear_everything() {
    t_sz = 1;
}

void solve() {
    clear_everything();

    int n;
    cin >> n;
    vector<array<int, 4>> rec(n);
    vector<int> sy;
    for (auto &[xl, xr, yl, yr] : rec) {
        cin >> xl >> yl >> xr >> yr;
        yr += 1;
        sy.push_back(yl);
        sy.push_back(yr);
    }
    vector<pair<pair<int, int>, ll>> cnt;
    sort(sy.begin(), sy.end());
    sy.resize(unique(sy.begin(), sy.end()) - sy.begin());

    int m = size(sy) - 1;
    vector<int> len_y(m);
    for (int i = 0; i < m; ++i) {
        len_y[i] = sy[i + 1] - sy[i];
    }

    int sz = 1 << __lg(m) + !!(m & (m - 1));
    len_y.resize(sz);
    vector<vector<pair<int, int>>> segments(sz * 2);
    for (auto [xl, xr, yl, yr] : rec) {
        yl = std::lower_bound(sy.begin(), sy.end(), yl) - sy.begin();
        yr = std::lower_bound(sy.begin(), sy.end(), yr) - sy.begin();
        for (int l = yl + sz, r = yr + sz; l < r; l >>= 1, r >>= 1) {
            if (l & 1) {
                segments[l++].push_back({xl, xr});
            }
            if (r & 1) {
                segments[--r].push_back({xl, xr});
            }
        }
    }

    auto dfs = [&](auto self, int root, int v) -> void {
        vector<pair<int, pair<int, int>>> stk;
//        cout << "vertex " << v << ":" << endl;
        for (int i = 0; i < segments[v].size(); ++i) {
            auto [l, r] = segments[v][i];
//            cout << "{" << l << ", " << r << "}\n";
            auto [r1, r23] = split(root, {l, 0});
            auto [r2, r3] = split(r23, {r + 2, -1});
            auto key_r1 = rightest_key(r1);
            int lx = l, rx = r;
            if (key_r1.second + 1 >= l) {
                lx = min(lx, key_r1.first);
                rx = max(rx, key_r1.second);
                auto [r1_l, r1_r] = split(r1, {key_r1.first, key_r1.second - 1});
                r2 = merge(r1_r, r2);
                r1 = r1_l;
            }
            rx = max(rx, rightest_key(r2).second);
//            cout << lx << " " << rx << endl;
            stk.push_back({r2, {}});
            // when solving for 25%, be aware that this might not create any new guys
            stk.back().second = {lx, rx};
            int new_node = create(Node({lx, rx}));
            root = merge(r1, merge(new_node, r3));
        }
        if (v >= sz) {
//            cout << "leaf " << v << endl;
            apply_x(root, len_y[v - sz]);
        } else {
            self(self, root, v * 2);
            self(self, root, v * 2 + 1);
        }
        for (int i = int(size(stk)) - 1; i >= 0; --i) {
            auto [add, seg] = stk[i];
            auto [r1, r23] = split(root, {seg.first, seg.second - 1});
            auto [r2, r3] = split(r23, seg);
            if (t[r2].added) {
                cnt.push_back(pair{t[r2].key, t[r2].added});
            }
            // delete r2
            root = merge(r1, merge(add, r3));
        }
    };
    dfs(dfs, 0, 1);
    sort(cnt.begin(), cnt.end());
    vector<pair<pair<int, int>, ll>> answer;
    for (auto [f, add] : cnt) {
        if (answer.empty() || answer.back().first != f) {
            answer.push_back({f, add});
        } else {
            answer.back().second += add;
        }
    }

    swap(cnt, answer);
    cout << cnt.size() << '\n';
    for (auto [u, v] : cnt) {
        cout << u.first << " " << u.second << " " << v << " " << 1 << '\n';
    }
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int test = 1;
    cin >> test;
    while (test--) {
        solve();
    }

    return 0;
}