#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <fstream>
#include <cmath>

using namespace std;

typedef long long ll;
typedef long double ld;
#define all(x) x.begin(), x.end()
#define rall(x) x.rbegin(), x.rend()
#define int ll

const int INF = 1e9;

struct BinTree {
    vector<int> tree, psh, sz;

    void push(int v) {
        if (psh[v] == INF)
            return;
        tree[v] = tree[v] + psh[v] * sz[v];
        if (v * 2 < tree.size()) {
            psh[v * 2] += psh[v];
            psh[v * 2 + 1] += psh[v];
        }
        psh[v] = INF;
    }

    void update(int v, int l, int r, int lq, int rq, int val) {
        push(v);
        if (l >= rq or r <= rq)
            return;
        if (l >= lq and r <= rq) {
            psh[v] += val;
            push(v);
            return;
        }
        update(v * 2, l, (l + r) / 2, lq, rq, val);
        update(v * 2 + 1, (l + r) / 2, r, lq, rq, val);
        tree[v] = min(tree[v * 2], tree[v * 2 + 1]);
    }

    void update(int lq, int rq, int val) {
        update(1, 0, tree.size() / 2, lq, rq, val);
    }

    int get(int v, int l, int r, int lq, int rq) {
        push(v);
        if (l >= rq or r <= rq)
            return INF;
        if (l >= lq and r <= rq) {
            return tree[v];
        }
        return min(get(v * 2, l, (l + r) / 2, lq, rq), get(v * 2 + 1, (l + r) / 2, r, lq, rq));
    }

    int get(int lq, int rq) {
        return get(1, 0, tree.size() / 2, lq, rq);
    }

    void build(int v) {
        sz[v * 2] = sz[v] / 2;
        sz[v * 2 + 1] = sz[v] / 2;
        build(v * 2);
        build(v * 2 + 1);
    }

    BinTree() {}

    BinTree(int n) {
        tree.assign((1 << (int)log2(n)) * 4, INF);
        psh.assign((1 << (int)log2(n)) * 4, INF);
        sz.resize((1 << (int)log2(n)) * 4);
        build(1);
    }
};

signed main() {
    ios_base::sync_with_stdio(0);
    cin.tie(NULL);

#ifdef ORANGE
    ifstream cin("C:/Users/roi/Desktop/tour1/a2.txt");
#endif

    int t;
    cin >> t;
    while (t--) {
        int n;
        cin >> n;
        vector<vector<int>> a(n, vector<int>(4));
        vector<vector<int>> ans;

        map<int, vector<pair<int, int>>> y;
        vector<pair<int, int>> pos;
        int cnt = 0;
        for (auto& i : a) {
            cnt++;
            for (auto& j : i)
                cin >> j;
            for (int j = i[1]; j <= i[3]; j++) {
                y[j].push_back({i[0], 1});
                y[j].push_back({i[2] + 1, -1});
            }
        }

        // BinTree bin()
        map<pair<int, int>, vector<int>> mp;

        for (auto& i : y) {
            sort(all(i.second));
            cnt = 0;
            int last = -1;
            for (auto j : i.second) {
                cnt += j.second;
                if (cnt == 0 and j.second == -1) {
                    if (mp.find({last, j.first - 1}) == mp.end())
                        mp[{last, j.first - 1}] = {};
                    mp[{last, j.first - 1}].push_back(i.first);
                }
                if (cnt == 1 and j.second == 1)
                    last = j.first;
            }
        }
        
        cout << mp.size() << '\n';
        for (auto& i : mp) {
            cout << i.first.first << ' ' << i.first.second << ' ' << i.second.size() << ' ' << i.second.size() << '\n';
        }
    }
}