#ifdef LOCAL
#define _GLIBCXX_DEBUG
#endif

#include <iostream>
#include <vector>
#include <map>
#include <algorithm>
#include <set>
#include <queue>

using namespace std;

typedef long long ll;

struct Node {
    int mn, cnt_mn;
    int b, e, cnt;
    int upd;

    Node(int mn = 0, int cnt_mn = 0, int b = 0, int e = 0, int upd = 0) : mn(mn), cnt_mn(cnt_mn),
                                                                          b(b), e(e), upd(upd) {}

    Node operator+(const Node &n) const {
        if (mn < n.mn) {
            return {mn, cnt_mn};
        } else if (mn == n.mn) {
            return {mn, cnt_mn + n.cnt_mn};
        } else {
            return {n.mn, n.cnt_mn};
        }
    }
};

struct SegmentTree {
    vector<int> base;
    vector<Node> data;

    SegmentTree(vector<int> &base, int n) : base(base), data(4 * n) {
        build(0, 0, n);
    }

    void build(int v, int l, int r) {
        if (l + 1 == r) {
            data[v] = {0, base[r] - base[l]};
            return;
        }
        int m = (l + r) / 2;
        build(2 * v + 1, l, m);
        build(2 * v + 2, m, r);
        data[v] = data[2 * v + 1] + data[2 * v + 2];
    }

    void push(int v) {
        data[2 * v + 1].mn += data[v].upd;
        data[2 * v + 1].upd += data[v].upd;
        data[2 * v + 2].mn += data[v].upd;
        data[2 * v + 2].upd += data[v].upd;
        data[v].upd = 0;
    }

    void update(int v, int l, int r, int lq, int rq, int x) {
        if (r <= lq || rq <= l) {
            return;
        }
        if (lq <= l && r <= rq) {
            data[v].mn += x;
            data[v].upd += x;
            return;
        }
        push(v);
        int m = (l + r) / 2;
        update(2 * v + 1, l, m, lq, rq, x);
        update(2 * v + 2, m, r, lq, rq, x);
        data[v] = data[2 * v + 1] + data[2 * v + 2];
    }

    Node get(int v, int l, int r, int lq, int rq) {
        if (r <= lq || rq <= l) {
            return {};
        }
        if (lq <= l && r <= rq) {
            return data[v];
        }
        push(v);
        int m = (l + r) / 2;
        auto p1 = get(2 * v + 1, l, m, lq, rq);
        auto p2 = get(2 * v + 2, m, r, lq, rq);
        return p1 + p2;
    }
};

struct Event {
    int x, y1, y2, type, id;

    Event(int x, int y1, int y2, int type, int id) : x(x), y1(y1), y2(y2), type(type), id(id) {}

    bool operator<(const Event &e) const {
        return x < e.x || (x == e.x && type < e.type);
    }
};

const int INF = 1e9 + 5;

void solve() {
    int n;
    cin >> n;
    vector<Event> evs;
    set<int> st_x, st_y;
    vector<int> v_y;
    vector<int> l, r;
    for (int i = 0; i < n; ++i) {
        int x1, y1, x2, y2;
        cin >> x1 >> y1 >> x2 >> y2;
        cout << x1 << ' ' << x2 << ' ' << 1 << ' ' << 1 << '\n';
    }

}

signed main() {
    ios_base::sync_with_stdio(false), cin.tie(nullptr);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}