#include <iostream>
#include <vector>
#include <algorithm>
#include <map>

using namespace std;

#define ll long long

int m, n;
vector<vector<int8_t>> ma;
vector<int> rows;
vector<int> cols;

void print()
{
	for (int y = m - 1; y >= 0; y--)
	{
		for (int x = 0; x < n; x++)
		{
			if (ma[x][y] == 0)
				cout << '.';
			else
				cout << (char)(ma[x][y] - 1 + 'a');
		}

		cout << endl;
	}
}

void movex(int dir)
{
	for (int y = 0; y < m; y++)
	{
		vector<int8_t> blocks;
		for (int x = 0; x < n; x++)
		{
			if (ma[x][y] != 0)
			{
				blocks.push_back(ma[x][y]);
				ma[x][y] = 0;
			}
		}

		rows[y] = blocks.size();

		int startx;
		if (dir > 0)
			startx = n - rows[y];
		else
			startx = 0;

		for (int dx = 0; dx < rows[y]; dx++)
		{
			ma[startx + dx][y] = blocks[dx];
		}
	}
}

void movey(int dir)
{
	for (int x = 0; x < n; x++)
	{
		vector<int8_t> blocks;
		for (int y = 0; y < m; y++)
		{
			if (ma[x][y] != 0)
			{
				blocks.push_back(ma[x][y]);
				ma[x][y] = 0;
			}
		}

		cols[x] = blocks.size();

		int starty;
		if (dir > 0)
			starty = m - cols[x];
		else
			starty = 0;

		for (int dy = 0; dy < cols[x]; dy++)
		{
			ma[x][starty + dy] = blocks[dy];
		}
	}
}

void move(char com)
{
	if (com == 'L')
		movex(-1);
	if (com == 'R')
		movex(1);
	if (com == 'D')
		movey(-1);
	if (com == 'U')
		movey(1);
}

void fastx(int dir)
{
	if ((cols[n - 1] - cols[0]) / dir >= 0)
		return;

	reverse(cols.begin(), cols.end());
}

void fasty(int dir)
{
	if ((rows[m - 1] - rows[0]) / dir >= 0)
		return;

	reverse(rows.begin(), rows.end());
}

void fast(char com)
{
	if (com == 'L')
		fastx(-1);
	if (com == 'R')
		fastx(1);
	if (com == 'D')
		fasty(-1);
	if (com == 'U')
		fasty(1);
}

void simple(char com)
{
	move(com);
	print();
}

void generate()
{
	int dir;
	if (cols[0] > cols[n - 1])
	{
		dir = -1;
	}
	else
	{
		dir = 1;
	}

	for (int y = 0; y < m; y++)
	{
		for (int x = 0; x < n; x++)
		{
			if (dir > 0)
			{
				if (n - x > rows[y])
					ma[x][y] = 0;
				else
					ma[x][y] = 1;
			}
			else
			{
				if (x >= rows[y])
					ma[x][y] = 0;
				else
					ma[x][y] = 1;
			}
		}
	}
}

const ll P = 1e9 + 7;

class pos
{
public:
	vector<vector<int8_t>> mat;

	ll hash;

	ll l = 0;
	ll r = 0;
	ll u = 0;
	ll d = 0;

	pos(vector<vector<int8_t>> ma)
	{
		mat = ma;

		int pos = 0;
		ll po = 1;

		for (int x = 0; x < n; x++)
		{
			for (int y = 0; y < m; y++)
			{
				po *= P;
				hash += ma[x][y] * po;
				pos++;
			}
		}
	}
};

map<ll, pos*> poss;

int main()
{
	int t;
	cin >> t;

	ll cph;
	for (int i = 0; i < t; i++)
	{
		cin >> m >> n;

		ma = vector<vector<int8_t>>(n, vector<int8_t>(m));
		rows = vector<int>(m);
		cols = vector<int>(n);

		for (int y = m - 1; y >= 0; y--)
		{
			for (int x = 0; x < n; x++)
			{
				char c;
				cin >> c;

				if (c == '.')
					ma[x][y] = 0;
				else
					ma[x][y] = c + 1 - 'a';
			}
		}

		string com;
		cin >> com;

		int first = -1;

		if (com[0] == 'L' || com[0] == 'R')
		{
			for (int j = 0; j < com.size(); j++)
			{
				if (com[j] == 'U' || com[j] == 'D')
				{
					first = j - 1;
					break;
				}
			}

			if (first == -1)
			{
				simple(com[com.size() - 1]);
				continue;
			}
		}
		else
		{
			for (int j = 0; j < com.size(); j++)
			{
				if (com[j] == 'L' || com[j] == 'R')
				{
					first = j - 1;
					break;
				}
			}

			if (first == -1)
			{
				simple(com[com.size() - 1]);
				continue;
			}
		}

		move(com[first]);
		move(com[first + 1]);

		pos* tp = new pos(ma);

		poss[tp->hash] = tp;
		cph = tp->hash;

		for (int j = first + 2; j < com.size(); j++)
		{
			if (com[j] == 'L')
			{
				if (poss[cph]->l != 0)
				{
					cph = poss[cph]->l;
				}
				else
				{
					ma = poss[cph]->mat;
					movex(-1);
					pos* tp2 = new pos(ma);
					poss[cph]->l = tp2->hash;
					cph = tp2->hash;
					if (poss[cph] == nullptr)
						poss[cph] = tp2;
				}
			}
			if (com[j] == 'R')
			{
				if (poss[cph]->r != 0)
				{
					cph = poss[cph]->r;
				}
				else
				{
					ma = poss[cph]->mat;
					movex(1);
					pos* tp2 = new pos(ma);
					poss[cph]->r = tp2->hash;
					cph = tp2->hash;
					if (poss[cph] == nullptr)
						poss[cph] = tp2;
				}
			}
			if (com[j] == 'D')
			{
				if (poss[cph]->d != 0)
				{
					cph = poss[cph]->d;
				}
				else
				{
					ma = poss[cph]->mat;
					movey(-1);
					pos* tp2 = new pos(ma);
					poss[cph]->d = tp2->hash;
					cph = tp2->hash;
					if (poss[cph] == nullptr)
						poss[cph] = tp2;
				}
			}
			if (com[j] == 'U')
			{
				if (poss[cph]->u != 0)
				{
					cph = poss[cph]->u;
				}
				else
				{
					ma = poss[cph]->mat;
					movey(1);
					pos* tp2 = new pos(ma);
					poss[cph]->u = tp2->hash;
					cph = tp2->hash;
					if (poss[cph] == nullptr)
						poss[cph] = tp2;
				}
			}
		}

		ma = poss[cph]->mat;
		print();
	}

	return 0;
}