#include <iostream>
#include <map>
#include <cassert>
#include <vector>
#include <algorithm>
#include <map>
#include <string>
using namespace std;
using ll = long long;

const ll MOD = 1000000007;
const ll MAXN = 1e6 + 123;
ll pw28[MAXN];

enum Dirs{right, up, left, down};

void move_dumb(vector<string>& f, Dirs dir) {
    int n = f.size();
    int m = f[0].size();
    switch (dir) {
        case Dirs::right:
            for (int i = 0; i < n; ++i) {
                int curj = m - 1;
                for (int j = m - 1; j >= 0; --j) if (f[i][j] != '.') {
                    swap(f[i][curj--], f[i][j]);
                }
            }
            break;
        case Dirs::up:
            for (int j = 0; j < m; ++j) {
                int curi = 0;
                for (int i = 0; i < n; ++i) if (f[i][j] != '.') {
                    swap(f[curi++][j], f[i][j]);
                }
            }
            break;
        case Dirs::left:
            for (int i = 0; i < n; ++i) {
                int curj = 0;
                for (int j = 0; j < m; ++j) if (f[i][j] != '.') {
                    swap(f[i][curj++], f[i][j]);
                }
            }
            break;
        case Dirs::down:
            for (int j = 0; j < m; ++j) {
                int curi = n - 1;
                for (int i = n - 1; i >= 0; --i) if (f[i][j] != '.') {
                    swap(f[curi--][j], f[i][j]);
                }
            }
            break;
    }
}

void move_smart(vector<string>& f, ll& hsh, Dirs dir) {
    int n = f.size();
    int m = f[0].size();
    switch (dir) {
        case Dirs::right:
            for (int i = 0; i < n; ++i) {
                int curj = m - 1;
                for (int j = m - 1; j >= 0; --j) if (f[i][j] != '.') {
                    hsh -= pw28[i * m + j] * (f[i][j] - 'a' + 1) % MOD;
                    hsh += pw28[i * m + curj] * (f[i][j] - 'a' + 1) % MOD;
                    swap(f[i][curj--], f[i][j]);
                }
            }
            /*for (int i = 0; i < n; ++i) {
                if (f[i][0] == '.' || f[i][n - 1] != '.')
                    continue;
                int lb = 0, ub = m - 1;
                while (ub - lb > 1) {
                    int mb = (lb + ub) / 2;
                    if (f[i][mb] == '.')
                        ub = mb;
                    else
                        lb = mb;
                }
                for (int j = 0; j < ub; ++j)
                    hsh -= pw28[i * m + j] * (f[i][j] - 'a' + 1) % MOD;
                rotate(f[i].begin(), f[i].begin() + ub, f[i].end());
                for (int j = m - ub; j < m; ++j)
                    hsh += pw28[i * m + j] * (f[i][j] - 'a' + 1) % MOD;
            } */
            break;
        case Dirs::up:
            for (int j = 0; j < m; ++j) {
                int curi = 0;
                for (int i = 0; i < n; ++i) if (f[i][j] != '.') {
                    hsh -= pw28[i * m + j] * (f[i][j] - 'a' + 1) % MOD;
                    hsh += pw28[curi * m + j] * (f[i][j] - 'a' + 1) % MOD;
                    swap(f[curi++][j], f[i][j]);
                }
            }
            break;
        case Dirs::left:
            for (int i = 0; i < n; ++i) {
                int curj = 0;
                for (int j = 0; j < m; ++j) if (f[i][j] != '.') {
                    hsh -= pw28[i * m + j] * (f[i][j] - 'a' + 1) % MOD;
                    hsh += pw28[i * m + curj] * (f[i][j] - 'a' + 1) % MOD;
                    swap(f[i][curj++], f[i][j]);
                }
            }
            break;
        case Dirs::down:
            for (int j = 0; j < m; ++j) {
                int curi = n - 1;
                for (int i = n - 1; i >= 0; --i) if (f[i][j] != '.') {
                    hsh -= pw28[i * m + j] * (f[i][j] - 'a' + 1) % MOD;
                    hsh += pw28[curi * m + j] * (f[i][j] - 'a' + 1) % MOD;
                    swap(f[curi--][j], f[i][j]);
                }
            }
            break;
    }
    hsh = (hsh % MOD + MOD) % MOD;
}

ll get_hsh(const vector<string>& f) {
    ll pw = 1;
    ll ans = 0;
    for (auto& x : f) for (auto& y : x) {
        if (y != '.')
            ans += pw * (y - 'a' + 1);
        pw = pw * 28 % MOD;
    }
    return ans % MOD;
}

map<ll, vector<string>> hash_to_f;
map<ll, ll> hash_edg[4];

void solve() {
    int n, m;
    cin >> n >> m;
    vector<string> f(n);
    for (int i = 0; i < n; ++i)
        cin >> f[i];
    string pstr;
    cin >> pstr;
    int q = pstr.size();
    vector<Dirs> p(q);
    for (int i = 0; i < q; ++i) {
        if (pstr[i] == 'R')
            p[i] = Dirs::right;
        else if (pstr[i] == 'U')
            p[i] = Dirs::up;
        else if (pstr[i] == 'L')
            p[i] = Dirs::left;
        else if (pstr[i] == 'D')
            p[i] = Dirs::down;
    }
    bool only_oneside = true;
    for (int i = 0; i < q; ++i)
        only_oneside &= (int(p[0]) ^ int(p[i])) % 2 == 0;
    if (only_oneside) {
        move_dumb(f, p[q - 1]);
        for (int i = 0; i < n; ++i)
            cout << f[i] << '\n';
        return;
    }
    Dirs prev_dirs[2];

    for (int i = 1; i < q; ++i) if (int(p[i]) % 2 != int(p[0]) % 2) {
        prev_dirs[int(p[i - 1]) % 2] = p[i - 1];
        move_dumb(f, p[i - 1]);
        prev_dirs[int(p[i]) % 2] = p[i];
        move_dumb(f, p[i]);
        rotate(p.begin(), p.begin() + i + 1, p.end());
        q -= i + 1;
        p.resize(q);
        break;
    }

    ll fhsh = get_hsh(f);
    hash_to_f[fhsh] = f;

    for (auto dir : p) {
        if (prev_dirs[int(dir) % 2] == dir)
            continue;
        prev_dirs[int(dir) % 2] = dir;
        if (hash_edg[dir].find(fhsh) != hash_edg[dir].end()) {
            fhsh = hash_edg[dir][fhsh];
            continue;
        }
        f = hash_to_f[fhsh];
        ll nfhsh = fhsh;
        move_smart(f, nfhsh, dir);
        hash_to_f[nfhsh] = f;
        hash_edg[dir][fhsh] = nfhsh;
        hash_edg[int(dir) ^ 2][nfhsh] = fhsh;
        fhsh = nfhsh;
    }
    f = hash_to_f[fhsh];
    for (int i = 0; i < n; ++i)
        cout << f[i] << '\n';
}

signed main() {
    pw28[0] = 1;
    for (int i = 1; i < MAXN; ++i)
        pw28[i] = pw28[i - 1] * 28 % MOD;
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}
