#include <iostream>
#include <algorithm>
#include <set>
#include <vector>
#include <map>
using namespace std;
using ll = long long;

const ll MOD = 1033000000;

ll par_hash(pair<int, int> pr) { 
    if (pr.first == pr.second)
        return -1;
    return min(pr.first, pr.second) + max(pr.first, pr.second) * MOD; 
}

struct segment_updater {
    ll up = 0;
    ll sm_len = 0;
    ll max_len = 0;

    segment_updater() {}

    void add(ll y) {
        up = y;
    }

    void remove(ll y) {
        if (up == -1)
            return;
        sm_len += y - up;
        max_len = max(y - up, max_len);
        up = -1;
    }
};

map<ll, segment_updater> mpans;

struct rectangle {
    ll l;
    ll u;
    ll r;
    ll d;
};

pair<pair<vector<ll>, vector<ll>>, vector<vector<pair<ll, ll>>>> initialize(int n) {
    mpans.clear();
    vector<ll> cprx;
    vector<ll> cpry;
    vector<rectangle> rects(n);
    for (int i = 0; i < n; ++i) {
        cin >> rects[i].l >> rects[i].u >> rects[i].r >> rects[i].d;
        ++rects[i].r;
        ++rects[i].d;

        cprx.push_back(rects[i].l);
        cprx.push_back(rects[i].r);
        cpry.push_back(rects[i].u);
        cpry.push_back(rects[i].d);
    }
    sort(cprx.begin(), cprx.end());
    cprx.resize(unique(cprx.begin(), cprx.end()) - cprx.begin());
    sort(cpry.begin(), cpry.end());
    cpry.resize(unique(cpry.begin(), cpry.end()) - cpry.begin());
    int szy = cpry.size();
    for (auto& rect : rects) {
        rect.l = lower_bound(cprx.begin(), cprx.end(), rect.l) - cprx.begin();
        rect.r = lower_bound(cprx.begin(), cprx.end(), rect.r) - cprx.begin();
        rect.u = lower_bound(cpry.begin(), cpry.end(), rect.u) - cpry.begin();
        rect.d = lower_bound(cpry.begin(), cpry.end(), rect.d) - cpry.begin();
    }
    vector<vector<pair<ll, ll>>> events(szy);
    for (auto& rect : rects) {
        events[rect.u].push_back({rect.l, rect.r});
        events[rect.d].push_back({rect.r, rect.l});
    }
    return {{cprx, cpry}, events};
}

struct renada {
    int n;
    vector<int> t_;
    vector<int>::iterator t;

    void resize(int sz) {
        n = sz;
        t_.resize(n + 6);
        t = t_.begin() + 3;
    }

    void add(int l, int r, int x) {
        for (int i = l; i < r; ++i)
            t[i] += x;
    }

    void output() {
        for (int i = 0; i < n - 1; ++i)
            cout << t[i] << ' ';
        cout << endl;
    }

    int left(int i) {
        while (t[i - 1] > 0)
            --i;
        return i;
    }
    
    int right(int i) {
        while (t[i] > 0)
            ++i;
        return i;
    }
};

void solve() {
    int n;
    cin >> n;
    auto [cpr, events] = initialize(n);
    auto [cprx, cpry] = cpr;
    int szx = cprx.size();
    int szy = cpry.size();

    renada rnd;
    rnd.resize(szx);

    set<ll> pts;

    for (int cy = 0; cy < szy; ++cy) {
        map<ll, pair<ll, ll>> segment_bypoint;
        for (auto [l, r] : events[cy]) {
            pts.insert(l);
            pts.insert(r);
        }
        for (auto x : pts) {
            segment_bypoint[x] = {rnd.left(x), rnd.right(x)};
        }
        for (auto [l, r] : events[cy]) {
            if (r > l)
                rnd.add(l, r, 1);
            else
                rnd.add(r, l, -1);
        }
        map<ll, pair<ll, ll>> new_segment_bypoint;
        for (auto x : pts) {
            new_segment_bypoint[x] = {rnd.left(x), rnd.right(x)};
        }
        for (auto x : pts) {
            pair<ll, ll> sgold = segment_bypoint[x];
            ll hshold = par_hash(sgold);
            pair<ll, ll> sgnew = new_segment_bypoint[x];
            ll hshnew = par_hash(sgnew);
            if (hshold == hshnew)
                continue;
            mpans[hshold].remove(cpry[cy]);
            mpans[hshnew].add(cpry[cy]);
        }
    }
    mpans.erase(-1);
    cout << mpans.size() << '\n';
    for (auto [hsh, val] : mpans) {
        int l = hsh % MOD;
        int r = hsh / MOD;
        cout << cprx[l] << ' ' << cprx[r] - 1 << ' ' << val.sm_len << ' ' << val.max_len << '\n';
    }
}

signed main() {
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}
