#include <iostream>
#include <algorithm>
#include <set>
#include <vector>
#include <map>
using namespace std;
using ll = long long;

const ll MOD = 1033000000;

ll par_hash(pair<int, int> pr) { 
    if (pr.first == pr.second)
        return -1;
    return min(pr.first, pr.second) + max(pr.first, pr.second) * MOD; 
}

struct segment_updater {
    ll up = 0;
    ll sm_len = 0;
    ll max_len = 0;

    segment_updater() {}

    void add(ll y) {
        up = y;
    }

    void remove(ll y) {
        if (up == -1)
            return;
        sm_len += y - up;
        max_len = max(y - up, max_len);
        up = -1;
    }
};

map<ll, segment_updater> mpans;

struct rectangle {
    ll l;
    ll u;
    ll r;
    ll d;
};

pair<vector<rectangle>, pair<pair<vector<ll>, vector<ll>>, vector<vector<pair<ll, ll>>>>> initialize(int n) {
    mpans.clear();
    vector<ll> cprx;
    vector<ll> cpry;
    vector<rectangle> rects(n);
    for (int i = 0; i < n; ++i) {
        cin >> rects[i].l >> rects[i].u >> rects[i].r >> rects[i].d;
        ++rects[i].r;
        ++rects[i].d;

        cprx.push_back(rects[i].l);
        cprx.push_back(rects[i].r);
        cpry.push_back(rects[i].u);
        cpry.push_back(rects[i].d);
    }
    sort(cprx.begin(), cprx.end());
    cprx.resize(unique(cprx.begin(), cprx.end()) - cprx.begin());
    sort(cpry.begin(), cpry.end());
    cpry.resize(unique(cpry.begin(), cpry.end()) - cpry.begin());
    int szy = cpry.size();
    for (auto& rect : rects) {
        rect.l = lower_bound(cprx.begin(), cprx.end(), rect.l) - cprx.begin();
        rect.r = lower_bound(cprx.begin(), cprx.end(), rect.r) - cprx.begin();
        rect.u = lower_bound(cpry.begin(), cpry.end(), rect.u) - cpry.begin();
        rect.d = lower_bound(cpry.begin(), cpry.end(), rect.d) - cpry.begin();
    }
    vector<vector<pair<ll, ll>>> events(szy);
    for (auto& rect : rects) {
        events[rect.u].push_back({rect.l, rect.r});
        events[rect.d].push_back({rect.r, rect.l});
    }
    return {rects, {{cprx, cpry}, events}};
}

struct renada {
    int n;
    vector<int> t;
    vector<int> mod;

    void resize(int sz) {
        n = sz;
        t.assign(2 * n + 9, 0);
        mod.assign(2 * n + 9, 0); 
    }

    void add(int ind, int lnd, int rnd, int l, int r, int x) {
        if (l <= lnd && rnd <= r) {
            t[ind] += x;
            mod[ind] += x;
            return;
        }
        if (l >= rnd || lnd >= r)
            return;
        int mnd = (lnd + rnd) / 2;
        int chd = ind + (mnd - lnd) * 2;
        add(ind + 1, lnd, mnd, l, r, x);
        add(chd, mnd, rnd, l, r, x);
        t[ind] = min(t[ind + 1], t[chd]) + mod[ind];
    }


    void add(int l, int r, int x) {
        add(0, -1, n + 1, l, r, x);
    }

    int left(int ind, int lnd, int rnd, int i) {
        if (i <= lnd)
            return i;
        if (t[ind] > 0)
            return lnd;
        if (rnd - lnd == 1)
            return i;
        int mnd = (lnd + rnd) / 2;
        int chd = ind + (mnd - lnd) * 2;
        i = left(chd, mnd, rnd, i);
        if (i > mnd)
            return i;
        return left(ind + 1, lnd, mnd, i);
    }

    int right(int ind, int lnd, int rnd, int i) {
        if (i >= rnd)
            return i;
        if (t[ind] > 0)
            return rnd;
        if (rnd - lnd == 1)
            return i;
        int mnd = (lnd + rnd) / 2;
        int chd = ind + (mnd - lnd) * 2;
        i = right(ind + 1, lnd, mnd, i);
        if (i < mnd)
            return i;
        return right(chd, mnd, rnd, i);
    }

    int left(int i) {
        return left(0, -1, n + 1, i);
    }
    
    int right(int i) {
        return right(0, -1, n + 1, i);
    }
};

void solve() {
    int n;
    cin >> n;
    auto [rects, jojo] = initialize(n);
    auto [cpr, events] = jojo;
    auto [cprx, cpry] = cpr;
    int szx = cprx.size();
    int szy = cpry.size();

    renada rnd;
    rnd.resize(szx);

    set<ll> stans;

    for (int cy = 0; cy < szy; ++cy) {
        set<ll> pts;
        for (auto [l, r] : events[cy]) {
            pts.insert(l);
            pts.insert(r);
        }
        for (auto [l, r] : events[cy]) {
            if (r > l)
                rnd.add(l, r, 1);
            else
                rnd.add(r, l, -1);
        }
        for (auto x : pts) {
            pair<ll, ll> sg = {rnd.left(x), rnd.right(x)};
            stans.insert(par_hash(sg));
        }
    }
    stans.erase(-1);
    cout << stans.size() << '\n';
    for (auto hsh : stans) {
        int l = hsh % MOD;
        int r = hsh / MOD;
        ll smlen = 0;
        ll maxlen = 0;
        
        cout << cprx[l] << ' ' << cprx[r] - 1 << ' ' << smlen << ' ' << maxlen << '\n';
    }
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    int t;
    cin >> t;
    while (t--) {
        solve();
    }
}
