#include <iostream>
#include <vector>
#include <set>
#include <map>
#include <algorithm>
#include <string>

using ll = long long;
using ull = unsigned long long;
#define INF 1'000'000'000
#define LINF 1'000'000'000'000'000'000

int dir(char c)
{
    if (c == 'L' || c == 'R') return 1;
    else return -1;
}

char inverse(char c)
{
    if (c == 'L') return 'R';
    if (c == 'R') return 'L';
    if (c == 'U') return 'D';
    if (c == 'D') return 'U';
}

std::string q, head, body;
void parseQ()
{
    head.clear(); body.clear();
    std::reverse(q.begin(), q.end());
    head += q.back();
    q.pop_back();
    while(!q.empty() && dir(q.back()) == dir(head[0]))
    {
        head[0] = q.back();
        q.pop_back();
    }
    if (q.empty()) return;
    head += q.back();
    q.pop_back();

    while(!q.empty())
    {
        char c = q.back();
        q.pop_back();
        if (body.size() >= 1 && c == body[body.size() - 1]) continue;
        if (body.size() >= 2 && c == body[body.size() - 2]) continue;
        if (body.size() >= 1 && c == inverse(body[body.size() - 1]))
        {
            body.pop_back();
            continue;
        }
        body += c;
    }
}

int m, n;
std::vector<std::vector<char>> field;

struct Prmt
{
    std::vector<std::vector<std::pair<int, int>>> p;

    Prmt()
    {
        p.assign(m, std::vector<std::pair<int, int>>(n));
        for (int i = 0; i < m; ++i) for (int j = 0; j < n; ++j) p[i][j] = {i, j};
    }

    auto at(std::pair<int, int> ind) const
    {
        return p[ind.first][ind.second];
    }

    Prmt operator*(const Prmt& a) const
    {
        Prmt c;
        for (int i = 0; i < m; ++i) for (int j = 0; j < n; ++j)
        {
            c.p[i][j] = a.at(p[i][j]);
        }
        return c;
    }

    void mv(char c, Prmt base)
    {
        if (c == 'L')
        {
            for (int i = 0; i < m; ++i)
            {
                int ptr = 0;
                for (int j = 0; j < n; ++j)
                {
                    if (field[base.at(p[i][j]).first][base.at(p[i][j]).second] != '.')
                    {
                        std::swap(p[i][j], p[i][ptr]);
                        ++ptr;
                    }
                }
            }
        }
        if (c == 'R')
        {
            for (int i = 0; i < m; ++i)
            {
                int ptr = n - 1;
                for (int j = n - 1; j >= 0; --j)
                {
                    if (field[base.at(p[i][j]).first][base.at(p[i][j]).second] != '.')
                    {
                        std::swap(p[i][j], p[i][ptr]);
                        --ptr;
                    }
                }
            }
        }
        if (c == 'U')
        {
            for (int j = 0; j < n; ++j)
            {
                int ptr = 0;
                for (int i = 0; i < m; ++i)
                {
                    if (field[base.at(p[i][j]).first][base.at(p[i][j]).second] != '.')
                    {
                        std::swap(p[i][j], p[ptr][j]);
                        ++ptr;
                    }
                }
            }
        }
        if (c == 'D')
        {
            for (int j = 0; j < n; ++j)
            {
                int ptr = m - 1;
                for (int i = m - 1; i >= 0; --i)
                {
                    if (field[base.at(p[i][j]).first][base.at(p[i][j]).second] != '.')
                    {
                        std::swap(p[i][j], p[ptr][j]);
                        --ptr;
                    }
                }
            }
        }
    }
};

std::ostream& operator<<(std::ostream& out, const Prmt& a)
{
    for (int i = 0; i < m; ++i)
    {
        for (int j = 0; j < n; ++j)
        {
            out << "(" << a.p[i][j].first << "," << a.p[i][j].second << ") ";
        }
        out << '\n';
    }
    return out;
}

Prmt pow(const Prmt& a, int n)
{
    if (n == 1) return a;
    Prmt pw = pow(a, n/2);
    pw = pw*pw;
    if (n%2) pw = a*pw;
    return pw;
}

int main()
{
#ifdef LOCAL
    freopen("../input.txt", "r", stdin);
    freopen("../output.txt", "w", stdout);
#endif // LOCAL
    std::ios_base::sync_with_stdio(false);
    std::cin.tie(0);
    std::cout.tie(0);

    int T;
    std::cin >> T;
    while(T--)
    {
        std::cin >> m >> n;
        field.assign(m, std::vector<char>(n));
        for (int i = 0; i < m; ++i) for (int j = 0; j < n; ++j)
        {
            std::cin >> field[i][j];
        }

        std::cin >> q;
        parseQ();

        //std::cout << head << ' ' << body << "\n\n";

        Prmt init;
        for (auto c : head)
        {
            init.mv(c, Prmt());
        }

        //std::cout << init << '\n';

        if (body.size() >= 4)
        {
            Prmt a;
            for (int i = 0; i < 4; ++i)
            {
                a.mv(body[i], init);
            }
            init = a*init;
            //std::cout << init << '\n';
            a = Prmt();
            for (int i = 0; i < 4; ++i)
            {
                a.mv(body[i], init);
            }
            //std::cout << a << '\n';
            init = pow(a, body.size()/4 - 1)*init;
        }

        int ind = 0;
        while(ind + 4 < body.size()) ind += 4;
        for (; ind < body.size(); ++ind)
        {
            init.mv(body[ind], Prmt());
        }

        for (int i = 0; i < m; ++i)
        {
            for (int j = 0; j < n; ++j)
            {
                std::cout << field[init.p[i][j].first][init.p[i][j].second];
            }
            std::cout << '\n';
        }
    }

    return 0;
}
