#include <algorithm>
#include <cassert>
#include <iostream>
#include <string>
#include <vector>

constexpr int maxlog = 20;

void alignl(int n, int m, std::vector<std::vector<int>>& a) {
    for (int i = 0; i < n; i++) {
        int clast = 0;
        for (int j = 0; j < m; j++) {
            if (a[i][j] != 0) {
                a[i][clast++] = a[i][j];
            }
        }
        for (int j = clast; j < m; j++) {
            a[i][j] = 0;
        }
    }
}

void alignr(int n, int m, std::vector<std::vector<int>>& a) {
    for (int i = 0; i < n; i++) {
        int clast = m - 1;
        for (int j = m - 1; j >= 0; j--) {
            if (a[i][j] != 0) {
                a[i][clast--] = a[i][j];
            }
        }
        for (int j = clast; j >= 0; j--) {
            a[i][j] = 0;
        }
    }
}

void alignu(int n, int m, std::vector<std::vector<int>>& a) {
    for (int j = 0; j < m; j++) {
        int clast = 0;
        for (int i = 0; i < n; i++) {
            if (a[i][j] != 0) {
                a[clast++][j] = a[i][j];
            }
        }
        for (int i = clast; i < n; i++) {
            a[i][j] = 0;
        }
    }
}

void alignd(int n, int m, std::vector<std::vector<int>>& a) {
    for (int j = 0; j < m; j++) {
        int clast = n - 1;
        for (int i = n - 1; i >= 0; i--) {
            if (a[i][j] != 0) {
                a[clast--][j] = a[i][j];
            }
        }
        for (int i = clast; i >= 0; i--) {
            a[i][j] = 0;
        }
    }
}

std::string conv(std::string q) {
    int ud = 0;
    int lr = 0;
    std::vector<char> st;
    std::vector<bool> canpop;
    std::string res;
    for (char el : q) {
        if (el == 'L') {
            if (lr == 0) {
                lr = -1;
                st.emplace_back('L');
                canpop.emplace_back(false);
            }
            if (lr == 1) {
                lr = -1;
                if (!st.empty() && st.back() == 'R') {
                    st.pop_back();
                } else {
                    st.emplace_back('L');
                }
            }
        } else if (el == 'R') {
            if (lr == 0) {
                lr = 1;
                res.push_back('R');
            }
            if (lr == -1) {
                lr = 1;
                if (!st.empty() && st.back() == 'L') {
                    st.pop_back();
                } else {
                    st.emplace_back('R');
                }
            }
        } else if (el == 'U') {
            if (ud == 0) {
                ud = -1;
                res.push_back('U');
            }
            if (ud == 1) {
                ud = -1;
                if (!st.empty() && st.back() == 'D') {
                    st.pop_back();
                } else {
                    st.emplace_back('U');
                }
            }
        } else {
            if (ud == 0) {
                ud = 1;
                res.push_back('D');
            }
            if (ud == -1) {
                ud = 1;
                if (!st.empty() && st.back() == 'U') {
                    st.pop_back();
                } else {
                    st.emplace_back('D');
                }
            }
        }
    }
    for (auto el : st) {
        res.push_back(el);
    }
    return res;
}

void solve() {
    int n, m;
    std::cin >> n >> m;
    std::vector<char> alp;
    alp.emplace_back('.');
    std::vector<std::vector<int>> a(n, std::vector<int>(m));
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            char cur;
            std::cin >> cur;
            if (cur == '.') {
                a[i][j] = 0;
            } else {
                a[i][j] = alp.size();
                alp.emplace_back(cur);
            }
        }
    }
    std::string q;
    std::cin >> q;
    // q = conv(q);
    if (q.size() < 8) {
        for (char el : q) {
            if (el == 'U') {
                alignu(n, m, a);
            } else if (el == 'D') {
                alignd(n, m, a);
            } else if (el == 'L') {
                alignl(n, m, a);
            } else {
                alignr(n, m, a);
            }
        }
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                std::cout << alp[a[i][j]];
            }
            std::cout << '\n';
        }
    } else {
        std::string cycle = q.substr(q.size() - 4, 4);
        int cntcycle = 0;
        while (q.size() > 4 && q.substr(q.size() - 4, 4) == cycle) {
            q.pop_back();
            q.pop_back();
            q.pop_back();
            q.pop_back();
            cntcycle++;
        }
        for (auto el : q) {
            if (el == 'U') {
                alignu(n, m, a);
            } else if (el == 'L') {
                alignl(n, m, a);
            } else if (el == 'R') {
                alignr(n, m, a);
            } else if (el == 'D') {
                alignd(n, m, a);
            }
        }
        std::vector<std::vector<int>> nw = a;
        for (auto el : cycle) {
            if (el == 'U') {
                alignu(n, m, nw);
            } else if (el == 'L') {
                alignl(n, m, nw);
            } else if (el == 'R') {
                alignr(n, m, nw);
            } else if (el == 'D') {
                alignd(n, m, nw);
            }
        }
        std::vector<std::pair<int, int>> poss(alp.size());
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (nw[i][j] != 0) {
                    poss[nw[i][j]] = {i, j};
                }
            }
        }
        std::vector<std::vector<std::pair<int, int>>> jmp0(n, std::vector<std::pair<int, int>>(m));
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                if (a[i][j] != 0) {
                    jmp0[i][j] = poss[a[i][j]];
                } else {
                    jmp0[i][j] = {i, j};
                }
            }
        }
        std::vector<std::vector<std::vector<std::pair<int, int>>>> jp(maxlog, std::vector<std::vector<std::pair<int, int>>>(n, std::vector<std::pair<int, int>>(m)));
        jp[0] = jmp0;
        for (int t = 1; t < maxlog; t++) {
            for (int i = 0; i < n; i++) {
                for (int j = 0; j < m; j++) {
                    auto [x, y] = jp[t - 1][i][j];
                    jp[t][i][j] = jp[t - 1][x][y];
                }
            }
        }
        std::vector<std::vector<std::pair<int, int>>> trans(n, std::vector<std::pair<int, int>>(m));
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                trans[i][j] = {i, j};
            }
        }
        for (int t = maxlog - 1; t >= 0; t--) {
            if ((cntcycle >> t) & 1) {
                auto oldtrans = trans;
                for (int i = 0; i < n; i++) {
                    for (int j = 0; j < m; j++) {
                        auto [x, y] = jp[t][i][j];
                        trans[i][j] = oldtrans[x][y];
                    }
                }
            }
        }
        std::vector<std::vector<int>> newa(n, std::vector<int>(m));
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                auto [x, y] = trans[i][j];
                newa[i][j] = a[x][y];
            }
        }
        for (int i = 0; i < n; i++) {
            for (int j = 0; j < m; j++) {
                std::cout << alp[newa[i][j]];
            }
            std::cout << '\n';
        }
    }
}

int main() {
    int t;
    std::cin >> t;
    for (int i = 0; i < t; i++) {
        solve();
    }
    return 0;
}
