/*
 * 1) покрасить в + все вершины, у которых есть хотя бы одно положительное ребро
 * 2) найти все рисковые положительные ребра
 * 3) задать приоритеты вершин согласно рисковым положительным ребрам
 * 4) найти все испорченные отрицательные ребра, отсортировать их в рисковом порядке (не используется)
 * 5) для каждого испорченного ребра
 *   - сделать обе вершины 0
 *   - вернуть вершины в ответное состояние
 * 6) пройти по всем вершинам, присвоить им нужное состояние
 * */

//#pragma GCC optimize("Ofast")
#define _GLIBCXX_DEBUG
#include <bits/stdc++.h>
#define fastio

using namespace std;

//#define int long long
#ifdef fastio
#define endl '\n'
#endif
#define all(x) x.begin(), x.end()
typedef long long ll;
typedef long double ld;
typedef pair<int, int> pii;

struct Edge {
    int a, b, c;
};

int n, m;
bool ok = true;
vector<Edge> edges;
vector<pii> ans;
vector<int> needed;
vector<int> state;
vector<vector<int>> g;
vector<vector<Edge>> broken;
vector<int> used;

void clear() {
    ok = true;
    edges.clear();
    ans.clear();
    needed.clear();
    state.clear();
    g.clear();
    broken.clear();
    used.clear();
}

void make(int a, int d) {
    if (state[a] == d) return;
    ans.emplace_back(a, d);
    state[a] = d;
}

void handle(const Edge &ed) {

    make(ed.a, 0);
    make(ed.b, 0);
    if (needed[ed.a]) {
        assert(!needed[ed.b]);
        make(ed.a, 1);
    } else if (needed[ed.b]) {
        make(ed.b, 1);
    }
}

void handle(int v, int p) {
    if (used[v] == 2) return;
    if (used[v] == 1) {
        ok = false;
        return;
    }
    used[v] = 1;
    for (const auto &u : g[v]) {
        handle(u, -1);
    }
    for (const auto &ed : broken[v]) {
        int other;
        if (ed.a == v) {
            other = ed.b;
        } else {
            other = ed.a;
        }
        if (other != p) handle(other, v);
        handle(ed);
    }
    broken[v].clear();
    used[v] = 2;
}



void solve() {
    clear();
    cin >> n >> m;

    edges.resize(m);
    state.resize(n, 0);
    needed.resize(n, false);
    g.resize(n);
    broken.resize(n);
    used.resize(n, 0);

    for (int i = 0; i < m; ++i) {
        int a, b, c;
        cin >> a >> b >> c;
        --a, --b;
        edges[i] = {a, b, c};
        if (c == 1) {
            make(a, 1);
            make(b, 1);
        }
    }

    for (int i = 0; i < n; ++i) {
        int d;
        cin >> d;
        needed[i] = d;
    }

    // проверяем элементарные противоречия
    for (int i = 0; i < m; ++i) {
        if (!ok) break;
        if (edges[i].c == 1) {
            if (!needed[edges[i].a] && !needed[edges[i].b]) {
                ok = false;
            }
        } else if (edges[i].c == 0) {
            if (needed[edges[i].a] && needed[edges[i].b]) {
                ok = false;
            }
        } else {
            exit(-1);
        }
    }
    vector<Edge> e;
    for (int i = 0; i < m; ++i) {
        if (edges[i].c == 1) continue;
        if (!state[edges[i].a] || !state[edges[i].b]) {
            // ребро не было сломано
            continue;
        }
        broken[edges[i].a].push_back(edges[i]);
        broken[edges[i].b].push_back(edges[i]);
        e.push_back(edges[i]);
    }
    // создаем приоритеты в обработке ребер
    for (int i = 0; i < m; ++i) {
        if (!ok) break;
        if (edges[i].c == 0) continue;
        auto a = edges[i].a, b = edges[i].b;
        if (needed[a] && !needed[b]) {
            swap(a, b);
        }
        if (needed[a] && needed[b]) continue;
        assert(!needed[a] && needed[b]);
        // сначала обрабатываем ребра с b, потом с a
        if (broken[a].size() > 0 && broken[b].size() > 0) {
            g[b].push_back(a);
        }
    }
    if (!ok) {
        cout << "NO" << endl;
        return;
    }
    for (int i = 0; i < n; ++i) {
        if (used[i] != 2) {
            handle(i, -1);
        }
    }
    vector<pii> operations;
    for (int i = 0; i < n; ++i) {
        if (state[i] == needed[i]) continue;
        operations.push_back({needed[i], i});
    }
    sort(all(operations));
    for (const auto [t, i] : operations) {
        make(i, t);
    }
    if (!ok) {
        cout << "NO" << endl;
        return;
    }
    cout << "YES" << endl;
    cout << -1 << endl;
//    cout << ans.size() << endl;
//    for (const auto &[a, b] : ans) {
//        assert(0 <= a && a < n);
//        assert(b == 0 || b == 1);
//        cout << a + 1 << " " << b << endl;
//    }
}

signed main() {
#ifdef ROMALOCAL
    freopen("/home/roi/work/code1/in.txt", "r", stdin);
#endif
#ifdef fastio
    cin.tie(nullptr);
    ios::sync_with_stdio(false);
#endif

    int t;
    cin >> t;
    while (t--) {
        solve();
    }

    return 0;
}