#include <iostream>
#include <vector>
#include <algorithm>

std::vector<int64_t> targets;
std::vector<std::vector<std::pair<int64_t, int64_t>>> graph;

void input_data() {
	int64_t n, m;
	std::cin >> n >> m;

	graph.assign(n, {});
	for (int64_t i = 0; i < m; ++i) {
		int64_t a, b, c;
		std::cin >> a >> b >> c;

		graph[a - 1].emplace_back(b - 1, c);
		graph[b - 1].emplace_back(a - 1, c);
	}

	targets.resize(n);
	for (int64_t& target : targets) {
		std::cin >> target;
	}
}

std::vector<int64_t> states;
std::vector<std::pair<int64_t, int64_t>> actions;

bool dfs_set(int64_t v, int64_t state) {
	if (states[v] == state) {
		return true;
	}

	for (auto [u, target] : graph[v]) {
		if (target != state) {
			if (targets[u] == state) {
				return false;
			} else {
				if (!dfs_set(u, 1 - state)) {
					return false;
				}
			}
		}
	}

	actions.emplace_back(v, state);
	states[v] = state;

	for (auto [u, target] : graph[v]) {
		if (target == state && targets[u] != state) {
			if (!dfs_set(u, state) || !dfs_set(u, 1 - state)) {
				return false;
			}
		}
	}

	return true;
}

bool try_set() {
	states.assign(targets.size(), 0);
	actions.clear();
	actions.reserve(targets.size());

	for (int64_t v = 0; v < graph.size(); ++v) {
		if (!dfs_set(v, targets[v])) {
			return false;
		}
	}
	return true;
}

int main() {
	int64_t t;
	std::cin >> t;

	for (int64_t i = 0; i < t; ++i) {
		input_data();

		if (try_set()) {
			std::cout << "YES\n";
			std::cout << actions.size() << '\n';
			for (auto [v, state] : actions) {
				std::cout << v + 1 << ' ' << state << '\n';
			}
		} else {
			std::cout << "NO\n";
		}
	}
}
