#include <iostream>
#include <vector>
#include <algorithm>
#include <random>
#include <cmath>

struct Edge {
	int64_t end;
	int64_t target;
	int64_t state;
};

std::vector<int64_t> targets;
std::vector<std::vector<Edge>> graph;

void input_data() {
	int64_t n, m;
	std::cin >> n >> m;

	graph.assign(n, {});
	for (int64_t i = 0; i < m; ++i) {
		int64_t a, b, c;
		std::cin >> a >> b >> c;

		graph[a - 1].push_back(Edge{ b - 1, c, 0 });
		graph[b - 1].push_back(Edge{ a - 1, c, 0 });
	}

	targets.resize(n);
	for (int64_t& target : targets) {
		std::cin >> target;
	}
}

std::vector<int64_t> states;
std::vector<std::pair<int64_t, int64_t>> actions;

bool simulate() {
	states.resize(targets.size(), 0);

	int64_t n_wrong = 0;
	for (int64_t i = 0; i < targets.size(); ++i) {
		if (targets[i] != 0) {
			++n_wrong;
		}
	}

	for (auto& vertex : graph) {
		for (auto [end, target, state] : vertex) {
			if (target != state) {
				++n_wrong;
			}
		}
	}

	std::mt19937_64 rand(3292398);
	for (int64_t i = 0; i < 1002020; ++i) {
		int64_t toggle = std::uniform_int_distribution<int64_t>(0ll, states.size())(rand);
		actions.emplace_back(toggle, 1 - states[toggle]);

		states[toggle] = 1 - states[toggle];
		if (states[toggle] != targets[toggle]) {
			++n_wrong;
		} else {
			--n_wrong;
		}

		for (auto& [end, target, state] : graph[toggle]) {
			if (states[end] == states[toggle]) {
				state = states[toggle];
			}

			if (state == target) {
				--n_wrong;
			}
			else {
				++n_wrong;
			}
		}

		if (n_wrong == 0) {
			return true;
		}
	}
	return false;
}

int main() {
	int64_t t;
	std::cin >> t;

	for (int64_t i = 0; i < t; ++i) {
		input_data();

		if (simulate()) {
			std::cout << "YES\n";
			std::cout << actions.size() << '\n';
			for (auto [v, state] : actions) {
				std::cout << v + 1 << ' ' << state << '\n';
			}
		}
		else {
			std::cout << "NO\n";
		}
	}
}
