#include <iostream>
#include <vector>
#include <limits>

using std::swap;

std::vector<int64_t> delays;
std::vector<int64_t> checkpoints;

void input_data() {
	int64_t n, m;
	std::cin >> n >> m;

	delays.resize(n);
	for (int64_t& delay : delays) {
		std::cin >> delay;
	}

	checkpoints.resize(m);
	for (int64_t& checkpoint : checkpoints) {
		std::cin >> checkpoint;
	}
	checkpoints.insert(checkpoints.begin(), 0);
}

int64_t time_to_next(int64_t saved, int64_t delay) {
	if (saved == checkpoints.size() - 1) {
		return std::numeric_limits<int64_t>::max();
	}

	return (checkpoints[saved + 1] - checkpoints[saved]) * delay;
}

struct Event {
	int64_t i;
	int64_t t;
	bool does_finish;
};

std::vector<Event> events;
std::vector<Event> new_events;

void add_events_before(int64_t t, int64_t i, int64_t& saved) {
	int64_t cur_t = time_to_next(saved, delays[i]);
	while (cur_t < t) {
		++saved;
		new_events.push_back(Event{ i, cur_t, saved == checkpoints.size() - 1 });
		cur_t = time_to_next(saved, delays[i]);
	}
}

int64_t add(int64_t k) {
	new_events.clear();
	new_events.reserve(delays.size() * checkpoints.size());

	int64_t saved = 0;
	for (auto [i, t, does_finish] : events) {
		add_events_before(t, k, saved);
		new_events.push_back(Event{ i, t, does_finish });
	}
	add_events_before(std::numeric_limits<int64_t>::max(), k, saved);

	swap(events, new_events);

	int64_t n_tp = 0;
	int64_t n_finished = 0;
	for (auto [i, t, does_finish] : events) {
		n_tp += k - n_finished;
		if (does_finish) {
			++n_finished;
		}
	}
	return n_tp;
}

int main() {
	input_data();
	for (int64_t k = 0; k < delays.size(); ++k) {
		std::cout << add(k) << '\n';
	}
}
