#include <iostream>
#include <vector>
#include <limits>
#include <algorithm>

using std::swap;

std::vector<int64_t> delays;
std::vector<int64_t> checkpoints;

void input_data() {
	int64_t n, m;
	std::cin >> n >> m;

	delays.resize(n);
	for (int64_t& delay : delays) {
		std::cin >> delay;
	}

	checkpoints.resize(m);
	for (int64_t& checkpoint : checkpoints) {
		std::cin >> checkpoint;
	}
	checkpoints.insert(checkpoints.begin(), 0);
}

int64_t time_to_next(int64_t saved, int64_t delay) {
	if (saved == checkpoints.size() - 1) {
		return std::numeric_limits<int64_t>::max();
	}

	return (checkpoints[saved + 1] - checkpoints[saved]) * delay;
}

struct Event {
	int64_t i;
	int64_t t;
};

std::vector<Event> events;
std::vector<int64_t> arrival_times;

void gen_all_events() {
	events.reserve(delays.size() * checkpoints.size());
	arrival_times.resize(delays.size() * checkpoints.size());

	std::vector<int64_t> saved(delays.size());
	while (true) {
		int64_t first = 0;
		for (int64_t i = 1; i < saved.size(); ++i) {
			if (time_to_next(saved[i], delays[i]) < time_to_next(saved[first], delays[first])) {
				first = i;
			}
		}

		if (saved[first] == checkpoints.size() - 1) {
			return;
		}

		events.push_back(Event{ first, time_to_next(saved[first], delays[first]) });

		++saved[first];
		arrival_times[first * checkpoints.size() + saved[first]] = events.size() - 1;
	}
}

int64_t n_leaves;
std::vector<int64_t> st_true_time;
std::vector<int64_t> st_true_time_to_sub;
std::vector<int64_t> st_n_finished;
std::vector<int64_t> st_n_finished_to_sub;

void build_st() {
	n_leaves = events.size();
	while (n_leaves & (n_leaves - 1)) {
		n_leaves &= n_leaves - 1;
	}
	n_leaves <<= 1;

	st_true_time.resize(events.size());
	st_true_time_to_sub.resize(2 * n_leaves - 1);
	st_n_finished.resize(events.size());
	st_n_finished_to_sub.resize(2 * n_leaves - 1);

	for (int64_t i = 0; i < events.size(); ++i) {
		st_true_time[i] = i;

		if (i != 0) {
			st_n_finished[i] = st_n_finished[i - 1];
			if (i - 1 == arrival_times[events[i - 1].i * checkpoints.size() + checkpoints.size() - 1]) {
				++st_n_finished[i];
			}
		}
	}
}

void push_true_time(int64_t v) {
	if (2 * v + 2 > st_true_time_to_sub.size()) {
		st_true_time[v - n_leaves + 1] -= st_true_time_to_sub[v];
	} else {
		st_true_time_to_sub[2 * v + 1] += st_true_time_to_sub[v];
		st_true_time_to_sub[2 * v + 2] += st_true_time_to_sub[v];
	}
	st_true_time_to_sub[v] = 0;
}

void push_n_finished(int64_t v) {
	if (2 * v + 2 > st_true_time_to_sub.size()) {
		st_n_finished[v - n_leaves + 1] -= st_n_finished_to_sub[v];
	}
	else {
		st_n_finished_to_sub[2 * v + 1] += st_n_finished_to_sub[v];
		st_n_finished_to_sub[2 * v + 2] += st_n_finished_to_sub[v];
	}
	st_n_finished_to_sub[v] = 0;
}

int64_t get_true_time(int64_t time, int64_t v = 0, int64_t vl = 0, int64_t vr = n_leaves) {
	push_true_time(v);

	if (vl + 1 == vr) {
		return st_true_time[vl];
	}

	int64_t vm = (vl + vr) / 2;
	if (time < vm) {
		return get_true_time(time, 2 * v + 1, vl, vm);
	} else {
		return get_true_time(time, 2 * v + 2, vm, vr);
	}
}

int64_t get_n_finished(int64_t time, int64_t v = 0, int64_t vl = 0, int64_t vr = n_leaves) {
	push_n_finished(v);

	if (vl + 1 == vr) {
		return st_n_finished[vl];
	}

	int64_t vm = (vl + vr) / 2;
	if (time < vm) {
		return get_n_finished(time, 2 * v + 1, vl, vm);
	} else {
		return get_n_finished(time, 2 * v + 2, vm, vr);
	}
}

void sub_true_time_after(int64_t time, int64_t v = 0, int64_t vl = 0, int64_t vr = n_leaves) {
	push_true_time(v);
	if (vl == time) {
		++st_true_time_to_sub[v];
		return;
	}

	int64_t vm = (vl + vr) / 2;
	if (time < vm) {
		sub_true_time_after(time, 2 * v + 1, vl, vm);
		sub_true_time_after(vm, 2 * v + 2, vm, vr);
	} else {
		sub_true_time_after(time, 2 * v + 2, vm, vr);
	}
}

void sub_n_finished_after(int64_t time, int64_t v = 0, int64_t vl = 0, int64_t vr = n_leaves) {
	push_n_finished(v);
	if (vl == time) {
		++st_n_finished_to_sub[v];
		return;
	}

	int64_t vm = (vl + vr) / 2;
	if (time < vm) {
		sub_n_finished_after(time, 2 * v + 1, vl, vm);
		sub_n_finished_after(vm, 2 * v + 2, vm, vr);
	}
	else {
		sub_n_finished_after(time, 2 * v + 2, vm, vr);
	}
}

std::vector<int64_t> n_tp;

void compute_n_tp_0() {
	n_tp.reserve(delays.size());
	n_tp.push_back(0);

	int64_t n_finished = 0;
	for (int64_t i = 0; i < events.size(); ++i) {
		n_tp.front() += delays.size() - n_finished - 1;

		if (i == arrival_times[events[i].i * checkpoints.size() + checkpoints.size() - 1]) {
			++n_finished;
		}
	}
}

void rem(int64_t k) {
	n_tp.push_back(n_tp.back());

	n_tp.back() -= get_true_time(arrival_times[k * checkpoints.size() + checkpoints.size() - 1]) + 2 - checkpoints.size();
	for (int64_t save = 1; save < checkpoints.size(); ++save) {
		n_tp.back() -= k - get_n_finished(arrival_times[k * checkpoints.size() + save]);
	}

	sub_n_finished_after(arrival_times[k * checkpoints.size() + checkpoints.size() - 1]);
	for (int64_t save = 1; save < checkpoints.size(); ++save) {
		sub_true_time_after(arrival_times[k * checkpoints.size() + save]);
	}
}

int main() {
	input_data();
	gen_all_events();
	build_st();
	compute_n_tp_0();

	for (int64_t k = delays.size() - 1; k > 0; --k) {
		rem(k);
	}

	std::reverse(n_tp.begin(), n_tp.end());
	for (auto res : n_tp) {
		std::cout << res << '\n';
	}
}
