#include <iostream>
#include <vector>
#include <limits>
#include <algorithm>

using std::swap;

std::vector<int64_t> delays;
std::vector<int64_t> checkpoints;

bool all_same_speed = true;

void input_data() {
	int64_t n, m;
	std::cin >> n >> m;

	delays.resize(n);
	for (int64_t& delay : delays) {
		std::cin >> delay;
		if (delay != delays[0]) {
			all_same_speed = false;
		}
	}

	checkpoints.resize(m);
	for (int64_t& checkpoint : checkpoints) {
		std::cin >> checkpoint;
	}
	checkpoints.insert(checkpoints.begin(), 0);
}

int64_t time_to_next(int64_t saved, int64_t delay) {
	if (saved == checkpoints.size() - 1) {
		return std::numeric_limits<int64_t>::max();
	}

	return (checkpoints[saved + 1] - checkpoints[saved]) * delay;
}

std::vector<int64_t> max_segments;
int64_t n_less_max = 0;

void compute_max_segments() {
	max_segments.resize(checkpoints.size() - 1);
	max_segments[0] = checkpoints[1] - checkpoints[0];
	for (int64_t i = 1; i + 1 < checkpoints.size(); ++i) {
		max_segments[i] = std::max(checkpoints[i + 1] - checkpoints[i], max_segments[i - 1]);
	}

	n_less_max = std::lower_bound(max_segments.begin(), max_segments.end(), max_segments.back()) - max_segments.begin();
}

int64_t n_less(int64_t len, int64_t delay) {
	return std::lower_bound(max_segments.begin(), max_segments.end(), len, [delay](int64_t l, int64_t r) {
		return delay * l < r;
	}) - max_segments.begin();
}

int64_t n_less_eq(int64_t len, int64_t delay) {
	return std::upper_bound(max_segments.begin(), max_segments.end(), len, [delay](int64_t l, int64_t r) {
		return l < delay * r;
	}) - max_segments.begin();
}

int64_t n_tp = 0;

int64_t add(int64_t k) {
	if (all_same_speed) {
		n_tp += n_less_max * (k - 1);
		n_tp += max_segments.size() * (k - 1);
		return n_tp;
	}

	for (int64_t i = 0; i + 1 < k; ++i) {
		n_tp += n_less(max_segments.back() * delays[i], delays[k - 1]);
		n_tp += n_less_eq(max_segments.back() * delays[k - 1], delays[i]);
	}
	return n_tp;
}

int main() {
	input_data();
	compute_max_segments();
	
	for (int64_t k = 1; k <= delays.size(); ++k) {
		std::cout << add(k) << '\n';
	}
}
