#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/tree_policy.hpp>

using namespace std;
using namespace __gnu_pbds;
 
typedef long long ll;
typedef tree<pair<ll, int>, null_type, less<pair<ll, int>>, rb_tree_tag, tree_order_statistics_node_update> ordered_set;

#pragma GCC optimize("O3")

class SegmentTree
{
public:
    SegmentTree(int n) : tree(n * 4) {}

    ll get(int v, int l, int r, int ql, int qr)
    {
        if (l >= qr || r <= ql)
            return 0;
        if (ql <= l && r <= qr)
            return tree[v].summ;
        int m = (l + r) / 2;
        return get(v * 2 + 1, l, m, ql, qr) + get(v * 2 + 2, m, r, ql, qr);
    }

    void add(int v, int l, int r, int p, ll x)
    {
        if (p < l || p >= r)
            return;
        if (l + 1 == r)
        {
            tree[v].summ += x;
            return;
        }
        int m = (l + r) / 2;
        add(v * 2 + 1, l, m, p, x);
        add(v * 2 + 2, m, r, p, x);
        tree[v].summ = tree[v * 2 + 1].summ + tree[v * 2 + 2].summ;
    }

private:
    struct Node
    {
        ll summ = 0;
    };

    vector<Node> tree;
};

int main()
{
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    ll n, m;
    cin >> n >> m;
    vector<ll> t(n);
    for (int i = 0; i < n; ++i)
        cin >> t[i];
    vector<ll> s(m);
    for (int i = 0; i < m; ++i)
        cin >> s[i];
    vector<ll> news;
    vector<ll> ssize;
    ll lasts = s[0];
    news.emplace_back(lasts);
    ssize.emplace_back(1);
    for (int i = 1; i < m; ++i)
    {
        if (s[i] - s[i - 1] > lasts)
        {
            lasts = s[i] - s[i - 1];
            news.emplace_back(lasts);
            ssize.emplace_back(1);
        }
        else
        {
            ++ssize.back();
        }
    }
    ordered_set sq;
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < news.size(); ++j)
        {
            sq.insert({news[j] * t[i], i});
        }
    }
    SegmentTree tree(sq.size());
    ordered_set b_only;
    ll result = 0;
    for (int i = 0; i < n; ++i)
    {
        for (int j = 0; j < news.size(); ++j)
        {
            result += (i - b_only.order_of_key({news[j] * t[i], i})) * ssize[j];
        }
        result += tree.get(0, 0, sq.size(), 0, sq.order_of_key({news.back() * t[i], i}) + 1);
        for (int j = 0; j < news.size(); ++j)
        {
            tree.add(0, 0, sq.size(), sq.order_of_key({news[j] * t[i], i}), ssize[j]);
        }
        b_only.insert({news.back() * t[i], i});
        cout << result << '\n';
    }
    return 0;
}
