#include<iostream>
#include<vector>
#include<string>
#include<cmath>
#include<algorithm>

#pragma GCC target("avx")
#pragma GCC optimize("unroll-loops")

#define ll long long
using namespace std;
const int INF = 1e9 + 7;
const ll INFL = 1e16 + 7;

#ifdef LOCAL
#define debug(x) cout << __LINE__ << ": " << #x << " => " << x << '\n';
#define debugv(x) cout << #x << ": "; for (auto xels : x) cout << xels << ' '; cout << '\n';
#define debugvv(x) cout << #x << ":\n"; for (auto xels : x) {for (auto xelsels : xels) cout << xelsels << ' '; cout << '\n';}
#else
#define debug(x) ;
#define debugv(x) ;
#define debugvv(x) ;
#endif



struct segment_tree {
    int n = 0;
    vector<int> tree = {};
    vector<ll> v = {};

    void buildtree(int l, int r, int ind) {
        if (r - l == 1) {
            tree[ind] = l;
            return;
        }
        int m = (l + r) / 2;
        buildtree(l, m, 2 * ind + 1);
        buildtree(m, r, 2 * ind + 2);
        int x1 = tree[2 * ind + 1];
        int x2 = tree[2 * ind + 2];
        if (v[x1] <= v[x2]) tree[ind] = x1;
        else tree[ind] = x2;
    }
    void build(int n_, vector<ll> v_) {
        n = n_; v = v_;
        tree.assign(4 * n, 0);
        buildtree(0, n, 0);
    }
    int mini(int L, int R, int l = 0, int r = -1, int ind = 0) {
        if (r == -1) r = n;
        if (r <= L || l >= R) {
            return -1;
        }
        if (l >= L && r <= R) {
            return tree[ind];
        }
        int m = (l + r) / 2;
        int x1 = mini(L, R, l, m, 2 * ind + 1);
        int x2 = mini(L, R, m, r, 2 * ind + 2);
        if (x2 == -1 || v[x1] <= v[x2]) return x1;
        return x2;
    }
    void update(int L, ll val, int l = 0, int r = -1, int ind = 0) {
        if (r == -1) r = n;
        if (r <= L || l > L) {
            return;
        }
        if (r - l == 1) {
            v[L] = val;
            return;
        }
        int m = (l + r) / 2;
        update(L, val, l, m, 2 * ind + 1);
        update(L, val, m, r, 2 * ind + 2);
        int x1 = tree[2 * ind + 1];
        int x2 = tree[2 * ind + 2];
        if (x2 == -1 || v[x1] <= v[x2]) tree[ind] = x1;
        else tree[ind] = x2;
    }
};


int solve() {
    int nall, m;
    cin >> nall >> m;
    vector<ll> t(nall);
    vector<int> s(m + 1, 0);
    for (int i = 0; i < nall; i++) {
        cin >> t[i];
    }
    for (int i = 0; i < m; i++) {
        cin >> s[i + 1];
    }
    for (int n = 1; n <= nall; n++) {
        int many = n;
        ll f = 0;
        vector<int> tp(n, 0);
        vector<ll> dist(n, 0);
        for (int i = 0; i < n; i++) {
            dist[i] = t[i] * (s[1] - s[0]);
        }
        segment_tree st;
        st.build(n, dist);
        while (many > 0) {
            int ind = st.mini(0, n);
            f += many - 1;
            tp[ind]++;
            if (tp[ind] == m) {
                many--;
                st.update(ind, INFL);
            } else {
                st.update(ind, t[ind] * (s[tp[ind] + 1] - s[tp[ind]]));
            }
        }
        cout << f << '\n';
    }
    return 0;
}

int main() {
#ifdef LOCAL
    string way_to_input = "C:\\Users\\roi\\tour2\\input.txt";
    string way_to_output = "C:\\Users\\roi\\tour2\\output.txt";
    freopen(way_to_input.c_str(), "r", stdin);
    freopen(way_to_output.c_str(), "w", stdout);
    while (!cin.eof()) {
        solve();
    }
#else
    ios_base::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    solve();
#endif
}