#include <iostream>
#include <vector>
#include <cassert>
#include <set>
#include <bitset>
using namespace std;

const int MAXN = 2e5 + 123;
vector<pair<int, int>> edg[MAXN];
vector<pair<int, int>> edges;
bitset<MAXN> state_vertex;
bitset<MAXN> state_edge;
bitset<MAXN> active_vertex;
bitset<MAXN> active_edge;

void initialize(int n, int m) {
    for (int i = 0; i < m; ++i) {
        int u, v, w;
        cin >> u >> v >> w;
        --u, --v;
        state_edge[i] = w;
        edges.push_back({u, v});
        edg[u].push_back({v, i});
        edg[v].push_back({u, i});
    }
    for (int i = 0; i < n; ++i) {
        int w;
        cin >> w;
        state_vertex[i] = w;
    }

}

vector<int> solve(int n, int m) {
    initialize(n, m);
    for (int i = 0; i < n; ++i)
        edg[i].clear();
    for (int i = 0; i < m; ++i) {
        auto [u, v] = edges[i];
        if (state_vertex[u] == state_vertex[v] && state_edge[i] != state_vertex[u])
            return {};
        if (state_vertex[u] != state_vertex[v]) {
            edg[u].push_back({v, i});
            edg[v].push_back({u, i});
        }
    }
    vector<int> badcnt(n, 0);
    for (int i = 0; i < n; ++i)
        active_vertex[i] = 1;
    for (int i = 0; i < m; ++i)
        active_edge[i] = 1;
    vector<int> vertex_badzero;
    for (int v = 0; v < n; ++v) {
        for (auto [u, i] : edg[v])
            badcnt[v] += state_vertex[v] ^ state_edge[i];
        if (badcnt[v] == 0)
            vertex_badzero.push_back(v);
    }
    vector<int> ans;
    while (vertex_badzero.size()) {
        int v = vertex_badzero.back();
        vertex_badzero.pop_back();
        if (state_vertex[v])
            ans.push_back(v);
        active_vertex[v] = 0;
        for (auto [u, i] : edg[v]) if (active_edge[i] && active_vertex[u]) {
            assert(state_edge[i] == state_vertex[v]);
            assert(state_vertex[v] ^ state_vertex[u]);
            active_edge[i] = 0;
            ans.push_back(u);
            ans.push_back(u);
            if (--badcnt[u] == 0)
                vertex_badzero.push_back(u);
        }
    }
    if (active_vertex.count() > 0)
        return {};
    if (ans.empty())
        ans = {0, 0};
    return ans;
}

void clear_global(int n, int m) {
    for (int i = 0; i < n; ++i)
        edg[i].clear();
    edges.clear();
    for (int i = 0; i < n; ++i)
        state_vertex[i] = active_vertex[i] = 0;
    for (int j = 0; j < m; ++j)
        state_edge[j] = active_edge[j] = 0;
}

signed main() {
    int t;
    cin >> t;
    while (t--) {
        int n, m;
        cin >> n >> m;
        vector<int> ans = solve(n, m);
        if (ans.empty()) {
            cout << "NO\n";
        } else if (ans[0] == -1) {
            cout << "YES\n";
            cout << -1 << '\n';
        } else {
            cout << "YES\n";
            if (ans.size() == 2 && ans[0] == ans[1]) {
                cout << 0 << '\n';
            } else {
                vector<bool> vals(n, false);
                cout << ans.size() << '\n';
                for (auto i : ans) {
                    vals[i] = vals[i] ^ true;
                    cout << i + 1 << ' ' << vals[i] << '\n';
                }
            }
        }
        clear_global(n, m);
    }
}
