#pragma GCC optimize("O3")
#include <iostream>
#include <vector>
#include <algorithm>
#include <set>

using namespace std;

#define int long long
#define all(v) (v).begin(), (v).end()

class Fenwick {
private:
	vector <int32_t> data;

public:
	Fenwick(int n) {
		data.assign(n, 0);
	}

	void add(int pos) {
		for (; pos < data.size(); pos |= pos + 1) {
			++data[pos];
		}
	}

	int get(int r) {
		int ans = 0;
		for (--r; r >= 0; r = (r & (r + 1)) - 1) {
			ans += data[r];
		}
		return ans;
	}
};

void solve() {
	int n, m; cin >> n >> m;
	vector <int> t(n), d0(m);
	for (auto& x : t) cin >> x;
	for (auto& x : d0) cin >> x;

	vector <pair <int, int>> d(m);
	d[0] = { d0[0], 1 };
	for (int i = 1; i < m; ++i) {
		d[i] = { d0[i] - d0[i - 1], 1 };
	}

	{
		vector <pair <int, int>> st;
		for (auto [l, c] : d) {
			if (!st.empty() && st.back().first >= l) {
				++st.back().second;
			}
			else {
				st.push_back({ l, 1 });
			}
		}
		d = st;
	}


	vector <int> big = t;
	sort(all(big));
	big.resize(unique(all(big)) - big.begin());

	vector <int> prs(big.size() + 1);
	const int block = 400;
	vector <int> bs((big.size() + 1) / block + 1);

	pair <int32_t, int32_t>** g = new pair <int32_t, int32_t>*[big.size()];
	for (int i = 0; i < big.size(); ++i) {
		g[i] = new pair <int32_t, int32_t>[d.size()];
	}
	for (int i = 0; i < d.size(); ++i) {
		int a = 0, b = 0;
		for (int j = 0; j < big.size(); ++j) {
			int a0 = big[j] * d.back().first / d[i].first;
			int b0 = big[j] * d[i].first / d.back().first;

			while (a < big.size() && big[a] <= a0) ++a;
			while (b < big.size() && big[b] <= b0) ++b;
			g[j][i] = { a, b };
		}
	}

	int ans = 0;
	for (int i = 0; i < n; ++i) {
		ans += 2 * m * i;
		int p = lower_bound(all(big), t[i]) - big.begin();

		for (int j = 0; j < d.size(); ++j) {
			int a = g[p][j].first;
			int b = g[p][j].second;
			int cnt = 0;
			cnt += prs[b] + bs[b / block];
			cnt += i - (prs[a] + bs[a / block]);
			ans -= cnt * d[j].second;
		}

		for (int i = p + 1; i < prs.size() && i % block != 0; ++i) {
			++prs[i];
		}
		for (int i = p / block + 1; i < bs.size(); ++i) {
			++bs[i];
		}

		cout << ans << '\n';
	}
}

signed main() {
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	int t = 1;
	//cin >> t;
	while (t--) {
		solve();
		cout << '\n';
	}
}
