#include <iostream>
#include <vector>
#include <map>
#include <valarray>

using namespace std;
using ll = long long;

struct Edge {
    ll v, u;
    bool on;
};

double rnd() {
    return double(rand()) / RAND_MAX;
}

void solve() {
    ll n, m;
    cin >> n >> m;
    vector<Edge> edges(m);
    map<pair<ll, ll>, ll> forE;
    for (auto &item: edges) {
        cin >> item.v >> item.u >> item.on;
        --item.v;
        --item.u;
        forE[{min(item.v, item.u), max(item.v, item.u)}] = item.on;
    }

    vector<ll> want(n);
    for (ll i = 0; i < n; ++i) {
        cin >> want[i];
    }

    vector<ll> cur(n);
    vector<pair<ll, ll>> act;
    vector<ll> curE(m);

    ll wrong = 0;
    for (int j = 0; j < n; ++j) {
        if (want[j] != cur[j]) {
            ++wrong;
        }
    }

    for (int j = 0; j < m; ++j) {
        if (curE[j] != edges[j].on) {
            ++wrong;
        }
    }

    double T = 1;
    for (int iter = 0; iter < 500; ++iter) {
        T *= 0.99;
        ll u = rand() % n;
        ll st = rand() % 2;
        ll wasSt = cur[u];
        cur[u] = st;
        act.emplace_back(u, st);

        vector<Edge> eNew = edges;
        for (ll eI = 0; eI < m; ++eI) {
            Edge &e = eNew[eI];
            if (cur[e.v] && cur[e.u]) {
                curE[eI] = 1;
            } else if (!cur[e.v] && !cur[e.u]) {
                curE[eI] = 0;
            }
        }

        ll newWrong = 0;
        for (int j = 0; j < n; ++j) {
            if (want[j] != cur[j]) {
                ++newWrong;
            }
        }
        for (int j = 0; j < m; ++j) {
            if (curE[j] != eNew[j].on) {
                ++newWrong;
            }
        }

        if (newWrong < wrong || exp((wrong - newWrong / T)) < rnd()) {
            edges = eNew;
            wrong = newWrong;
        } else {
            cur[u] = wasSt;
            act.pop_back();
        }

        if (wrong == 0) {
            cout << "YES\n";
            cout << act.size() << '\n';
            for (const auto &item: act) {
                cout << item.first + 1 << ' ' << item.second << '\n';
            }
            return;
        }
    }

    cout << "NO\n";
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    ll T;
    cin >> T;
    while (T--) {
        solve();
    }
    return 0;
}