#pragma gcc optimize("O3")

#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <map>
#include <numeric>

using namespace std;

using ll = long long;
using ld = long double;
using pii = pair <int, int>;
using pll = pair <ll, ll>;

const ll inf = 1e18;
const ll mxn = 1e9 + 7;
const ll mod = 1000000007;
const ld eps = 1e-6;

#define all(a) a.begin(), a.end()
#define pb push_back
#define vout(a) for (auto ug : a) {cout << ug << ' ';}; cout << endl;
#define debug(a) cerr << a << '\n';

const int T = 6e5 + 1;

struct segtree1 {
    ll t[T];

    void update (int i, ll val, int x, int lx, int rx) {
        if (rx - lx == 1) {
            t[x] += val;
            return;
        }
        int m = (lx + rx) >> 1;
        if (i < m) update(i, val, 2 * x + 1, lx, m);
        else update(i, val, 2 * x + 2, m, rx);
        t[x] = t[2 * x + 1] + t[2 * x + 2];
    }

    ll get (int l, int r, int x, int lx, int rx) {
        if (lx >= r || l >= rx) return 0ll;
        if (lx >= l && rx <= r) return t[x];
        int m = (lx + rx) >> 1;
        return get(l, r, 2 * x + 1, lx, m) + get(l, r, 2 * x + 2, m, rx);
    }
};

struct segtree2 {
    ll t[T];

    void update (int l, int r, ll val, int x, int lx, int rx) {
        if (lx >= r || l >= rx) return;
        if (lx >= l && rx <= r) {
            t[x] += val; return;
        }
        int m = (lx + rx) >> 1;
        update(l, r, val, 2 * x + 1, lx, m);
        update(l, r, val, 2 * x + 2, m, rx);
    }

    ll get (int i, int x, int lx, int rx) {
        if (rx - lx == 1) return t[x];
        int m = (lx + rx) >> 1;
        if (i < m) return t[x] + get(i, 2 * x + 1, lx, m);
        else return t[x] + get(i, 2 * x + 2, m, rx);
    }
};

const int M = 1.5e5 + 1;
int pos[M];

void solve() {
    int n, m; cin >> n >> m;
    vector <ll> t(n), s(m), d(m);
    for (int i = 0; i < n; ++i) {
        cin >> t[i];
    }
    for (int i = 0; i < m; ++i) {
        cin >> s[i];
    }
    d[0] = s[0];
    for (int i = 1; i < m; ++i) {
        d[i] = s[i] - s[i - 1];
    }
    ll ma = *max_element(all(d));
    for (int i = m - 1; i >= 0; --i) {
        pos[d[i]] = i;
    }

    vector <ll> lal;
    for (auto i : d) {
        if (lal.empty() || i > lal.back()) lal.push_back(i);
    }

    vector <ll> val(n);
    for (int i = 0; i < n; ++i) {
        val[i] = ma * t[i];
    }

    vector <int> order(n); iota(all(order), 0);
    auto cmp = [&] (int i, int j) {
        return t[i] < t[j] || (t[i] == t[j] && i > j);
    };
    auto cmp1 = [&] (pll x, pll y) {
        return x.first < y.first || (x.first == y.first && x.second > y.second);
    };
    sort(all(order), cmp);

    vector <int> ind(n);
    for (int i = 0; i < n; ++i) {
        ind[order[i]] = i;
    }

    vector <ll> A;
    for (ll i = 0; i < n; ++i) {
        A.emplace_back(t[i]);
    }
    sort(all(A));

    ll ans = 0;
    segtree1 st1; segtree2 st2;

    for (ll i = 0; i < n; ++i) {
        ans += st2.get(ind[i], 0, 0, n);
        ans += i * m;

        int pref = n;
        for (auto x : lal) {
            ll y = (val[i] + x - 1) / x;
            int index;

            if (x * y == val[i]) index = upper_bound(all(A), y) - A.begin();
            else index = lower_bound(all(A), y) - A.begin();
            
            if (index == pref) continue;

            ans += st1.get(index, pref, 0, 0, n) * pos[x];
            pref = index;
        }

        pref = n;
        for (auto x : lal) {
            ll y = (val[i] + x - 1) / x;
            int index = lower_bound(all(A), y) - A.begin();

            if (index == pref) continue;

            st2.update(index, pref, pos[x], 0, 0, n);
            pref = index;
        }

        st1.update(ind[i], 1, 0, 0, n);
        cout << ans << '\n';
    }
}

signed main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    cout.tie(nullptr);
    int tt = 1; // cin >> tt;
    while (tt--) solve();
}